<?php
/**
 * Implementation of the Custom Header feature
 * http://codex.wordpress.org/Custom_Headers
 *
 * @package Catch Everest
 * @since Catch Everest 1.0
 */

/**
 * Setup the WordPress core custom header feature.
 *
 * @uses catcheverest_header_style()
 *
 * @package Catch Everest
 */
function catcheverest_custom_header_setup() {
	$args = array(
		// Text color and image (empty to use none).
		'default-text-color'     => '000',
		'default-image'          => '',

		// Set height and width, with a maximum value for the width.
		'height'                 => 125,
		'width'                  => 300,

		// Support flexible height and width.
		'flex-height'            => true,
		'flex-width'             => true,

		// Random image rotation off by default.
		'random-default'         => false,

		// Callbacks for styling the header and the admin preview.
		'wp-head-callback'       => 'catcheverest_header_style',
	);

	if ( function_exists( 'has_custom_logo' ) ) {
		/* Previously, custom header was being used as logo, but with implementation of custom logo
		 * from WordPress version 4.5 onwards, we have migrated custom header to custom logo
		 * and Our custom field for header to core custom header
		 */
		$args['height']        = 320;
		$args['width']         = 900;
		$args['default-image'] = get_template_directory_uri() . '/images/header-image.jpg';
	}

	$args = apply_filters( 'catcheverest_custom_header_args', $args );

	add_theme_support( 'custom-header', $args );

}
add_action( 'after_setup_theme', 'catcheverest_custom_header_setup' );


if ( ! function_exists( 'catcheverest_header_style' ) ) :
	/**
	 * Styles the header image and text displayed on the blog
	 *
	 * @see catcheverest_custom_header_setup().
	 *
	 * @since Catch Everest 1.0
	 */
	function catcheverest_header_style() {

		// If no custom options for text are set, let's bail
		// get_header_textcolor() options: get_theme_support( 'custom-header', 'default-text-color' ) is default, hide text (returns 'blank') or any hex value
		if ( get_theme_support( 'custom-header', 'default-text-color' ) === get_header_textcolor() )
			return;
		// If we get this far, we have custom styles. Let's do this.
		?>
		<style type="text/css">
		<?php
			// Has the text been hidden?
			if ( 'blank' == get_header_textcolor() ) :
		?>
			#hgroup.with-logo { padding: 0; }
			#site-title,
			#site-description {
				position: absolute !important;
				clip: rect(1px 1px 1px 1px); /* IE6, IE7 */
				clip: rect(1px, 1px, 1px, 1px);
			}
		<?php
			// If the user has set a custom color for the text use that
			else :
		?>
			#site-title a,
			#site-description {
				color: #<?php echo get_header_textcolor(); ?> !important;
			}
		<?php endif; ?>
		</style>
		<?php
	}
endif; // catcheverest_header_style


if ( ! function_exists( 'catcheverest_featured_image' ) ) :
	/**
	 * Template for Featured Header Image from theme options
	 *
	 * To override this in a child theme
	 * simply create your own catcheverest_featured_image(), and that function will be used instead.
	 *
	 * @since Catch Everest Pro 1.0
	 */
	function catcheverest_featured_image() {
		//delete_transient( 'catcheverest_featured_image' );

		// Getting Data from Theme Options Panel
		global $catcheverest_options_settings, $catcheverest_options_defaults;
	   	$options = $catcheverest_options_settings;
		$defaults = $catcheverest_options_defaults;

		if ( !$catcheverest_featured_image = get_transient( 'catcheverest_featured_image' ) ) {

			echo '<!-- refreshing cache -->';

			// Check function exists for WordPress version >= 4.5
			if ( function_exists( 'has_custom_logo' ) ) {
				$header_image = get_header_image();

				if ( ! empty( $header_image ) ){
					$catcheverest_featured_image = '<div id="header-image">';

					// Header Image Link Target
					if ( !empty( $options['featured_header_image_base'] ) ) :
						$base = '_blank';
					else:
						$base = '_self';
					endif;

					// Header Image Title/Alt
					if ( !empty( $options['featured_header_image_alt'] ) ) :
						$title = $options['featured_header_image_alt'];
					else:
						$title = '';
					endif;

					// Header Image Link
					if ( !empty( $options['featured_header_image_url'] ) ) :
						$catcheverest_featured_image .= '<a title="' . esc_attr( $title ) . '" href="' . esc_url( $options['featured_header_image_url'] ) .'" target="' . $base . '"><img id="main-feat-img" class="wp-post-image" alt="' . esc_attr( $title ) . '" src="' . esc_url( $header_image ) . ' " /></a>';
					else:
						// if empty featured_header_image on theme options, display default
						$catcheverest_featured_image .= '<img id="main-feat-img" class="wp-post-image" alt="' . esc_attr( $title ) . '" src="' . esc_url( $header_image ) . '" />';
					endif;

				$catcheverest_featured_image .= '</div><!-- #header-image -->';
				}
			}
			elseif ( !empty( $options['featured_header_image'] ) ) {
				//@remove else block when WordPress 4.8 is released
				$catcheverest_featured_image = '<div id="header-image">';

					// Header Image Link Target
					if ( !empty( $options['featured_header_image_base'] ) ) :
						$base = '_blank';
					else:
						$base = '_self';
					endif;

					// Header Image Title/Alt
					if ( !empty( $options['featured_header_image_alt'] ) ) :
						$title = $options['featured_header_image_alt'];
					else:
						$title = '';
					endif;

					// Header Image Link
					if ( !empty( $options['featured_header_image_url'] ) ) :
						$catcheverest_featured_image .= '<a title="' . esc_attr( $title ) . '" href="'.$options['featured_header_image_url'] .'" target="'.$base.'"><img id="main-feat-img" class="wp-post-image" alt="' . esc_attr( $title ) . '" src="'.esc_url( $options['featured_header_image'] ).'" /></a>';
					else:
						// if empty featured_header_image on theme options, display default
						$catcheverest_featured_image .= '<img id="main-feat-img" class="wp-post-image" alt="' . esc_attr( $title ) . '" src="'.esc_url( $options['featured_header_image'] ).'" />';
					endif;

				$catcheverest_featured_image .= '</div><!-- #header-image -->';

			}

			set_transient( 'catcheverest_featured_image', $catcheverest_featured_image, 86940 );
		}

		echo $catcheverest_featured_image;
	} // catcheverest_featured_image
endif;


if ( ! function_exists( 'catcheverest_featured_page_post_image' ) ) :
	/**
	 * Template for Featured Header Image from Post and Page
	 *
	 * To override this in a child theme
	 * simply create your own catcheverest_featured_image_pagepost(), and that function will be used instead.
	 *
	 * @since Catch Everest Pro 1.0
	 */
	function catcheverest_featured_page_post_image() {
		global $post, $wp_query, $catcheverest_options_settings, $catcheverest_options_defaults;
	   	$options = $catcheverest_options_settings;
		$defaults = $catcheverest_options_defaults;
		$enableheaderimage =  $options['enable_featured_header_image'];
		$featured_image = $options['page_featured_image'];

		// Front page displays in Reading Settings
		$page_on_front = get_option('page_on_front') ;
		$page_for_posts = get_option('page_for_posts');

		// Get Page ID outside Loop
		$page_id = $wp_query->get_queried_object_id();

		//Individual Page/Post Image Setting
		$individual_featured_image = get_post_meta( $post->ID, 'catcheverest-header-image', true );

		if ( 'disable' == $individual_featured_image || ( 'default' == $individual_featured_image && 'disable' == $enableheaderimage ) ) {
			echo '<!-- Page/Post Disable Header Image -->';
		}
		elseif ( is_home() || is_archive() ) {
			if ( 'postpage' == $enableheaderimage ) {
				catcheverest_featured_image();
			}
			else {
				echo '<!-- Page/Post will not display in Home/Archive -->';
			}
		}
		elseif ( has_post_thumbnail() ) {
			echo '<div id="header-image">';

			if ( !empty( $options['featured_header_image_url'] ) ) {
				// Header Image Link Target
				if ( !empty( $options['featured_header_image_base'] ) ) :
					$base = '_blank';
				else:
					$base = '_self';
				endif;

				// Header Image Title/Alt
				if ( !empty( $options['featured_header_image_alt'] ) ) :
					$title = esc_attr( $options['featured_header_image_alt'] );
				else:
					$title = '';
				endif;

				$linkopen = '<a title="' . esc_attr( $title ) . '" href="'.esc_url( $options['featured_header_image_url'] ) .'" target="'.$base.'">';
				$linkclose = '</a>';
			}
			else {
				$linkopen = '';
				$linkclose = '';
			}

			echo $linkopen;

				if ( 'featured' == $individual_featured_image || ( $individual_featured_image=='default' && 'featured' == $featured_image ) ) {
					echo get_the_post_thumbnail($post->ID, 'featured', array('id' => 'main-feat-img'));
				}
				elseif ( 'slider' == $individual_featured_image || ( $individual_featured_image=='default' && 'slider' == $featured_image ) ) {
					echo get_the_post_thumbnail($post->ID, 'slider', array('id' => 'main-feat-img'));
				}
				else {
					echo get_the_post_thumbnail($post->ID, 'full', array('id' => 'main-feat-img'));
				}

			echo $linkclose;

			echo '</div><!-- #header-image -->';
		}
		else {
			catcheverest_featured_image();
		}
	} // catcheverest_featured_page_post_image
endif;


if ( ! function_exists( 'catcheverest_featured_overall_image' ) ) :
	/**
	 * Template for Featured Header Image from theme options
	 *
	 * To override this in a child theme
	 * simply create your own catcheverest_featured_pagepost_image(), and that function will be used instead.
	 *
	 * @since Catch Everest Pro 1.0
	 */
	function catcheverest_featured_overall_image() {
		global $post, $wp_query, $catcheverest_options_settings, $catcheverest_options_defaults;
		$options           = $catcheverest_options_settings;
		$defaults          = $catcheverest_options_defaults;
		$enableheaderimage =  $options['enable_featured_header_image'];
		$featured_image    = $options['page_featured_image'];

		// Front page displays in Reading Settings
		$page_on_front = get_option('page_on_front') ;
		$page_for_posts = get_option('page_for_posts');

		// Get Page ID outside Loop
		$page_id = $wp_query->get_queried_object_id();

		if ( 'allpage' == $enableheaderimage || ( 'homepage' == $enableheaderimage && ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) ) ) {
			catcheverest_featured_image();
		}
		elseif ( 'postpage' == $enableheaderimage || 'pagespostes' == $enableheaderimage ) {
			catcheverest_featured_page_post_image();
		}
		elseif ( 'excludehome' == $enableheaderimage  ) {
				// Check Excluding Homepage
				if ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) {
					return false;
				}
				else {
					catcheverest_featured_image();
				}
			}
		else {
			echo '<!-- Disable Header Image -->';
		}
	} // catcheverest_featured_overall_image
endif;


if ( ! function_exists( 'catcheverest_featured_image_display' ) ) :
	/**
	 * Display Featured Header Image
	 */
	function catcheverest_featured_image_display() {
		global $catcheverest_options_settings;

		// Getting data from Theme Options
	   	$options = $catcheverest_options_settings;
		$enableheaderimage =  $options['enable_featured_header_image'];

		if ( $options['featured_header_image_position'] == "before-header" ) {
			add_action( 'catcheverest_before_header', 'catcheverest_featured_overall_image', 10 );
		}
		elseif ( $options['featured_header_image_position'] == "after-sidebartop" ) {
			add_action( 'catcheverest_before_hgroup_wrap', 'catcheverest_featured_overall_image', 15 );
		}
		elseif ( $options['featured_header_image_position'] == "after-menu" ) {
			add_action( 'catcheverest_after_hgroup_wrap', 'catcheverest_featured_overall_image', 20 );
		}
		elseif ( $options['featured_header_image_position'] == "before-menu" ) {
			add_action( 'catcheverest_after_hgroup_wrap', 'catcheverest_featured_overall_image', 9 );
		}
	} // catcheverest_featured_image_display
endif;
add_action( 'catcheverest_before', 'catcheverest_featured_image_display' );