<?php
/**
 * Catch Everest Theme Options
 *
 * @package Catch Themes
 * @subpackage Catch_Everest
 * @since Catch Everest 1.0
 */
add_action( 'admin_init', 'catcheverest_register_settings' );
add_action( 'admin_menu', 'catcheverest_options_menu' );


/**
 * Enqueue admin script and styles
 *
 * @uses wp_register_script, wp_enqueue_script, wp_enqueue_media and wp_enqueue_style
 * @Calling jquery, jquery-ui-tabs,jquery-cookie, jquery-ui-sortable, jquery-ui-draggable, wp-color-picker
 */
function catcheverest_admin_scripts() {
    //jQuery Cookie
    wp_register_script( 'jquery-cookie', get_template_directory_uri() . '/inc/panel/js/jquery.cookie.min.js', array( 'jquery' ), '1.0', true );

    wp_enqueue_script( 'catcheverest_admin', get_template_directory_uri().'/inc/panel/js/admin.min.js', array( 'jquery', 'jquery-ui-tabs', 'jquery-cookie', 'jquery-ui-sortable', 'jquery-ui-draggable', 'wp-color-picker' ) );

    //For Media Uploader Box
    wp_enqueue_media();

    wp_enqueue_script( 'catcheverest_upload', get_template_directory_uri().'/inc/panel/js/add_image_scripts.min.js', array( 'jquery' ) );

    wp_enqueue_style( 'catcheverest_admin_style',get_template_directory_uri().'/inc/panel/admin.min.css', array( 'wp-color-picker' ), '1.0', 'screen' );

}
add_action( 'admin_print_styles-appearance_page_theme_options', 'catcheverest_admin_scripts' );


/*
 * Create a function for Theme Options Page
 *
 * @uses add_menu_page
 * @add action admin_menu
 */
function catcheverest_options_menu() {

    add_theme_page(
        __( 'Theme Options', 'catch-everest-pro' ),           // Name of page
        __( 'Theme Options', 'catch-everest-pro' ),           // Label in menu
        'edit_theme_options',                           // Capability required
        'theme_options',                                // Menu slug, used to uniquely identify the page
        'catcheverest_theme_options_do_page'             // Function that renders the options page
    );

}


/*
 * Register options and validation callbacks
 *
 * @uses register_setting
 * @action admin_init
 */
function catcheverest_register_settings() {
    register_setting( 'catcheverest_options', 'catcheverest_options', 'catcheverest_theme_options_validate' );
}


/*
 * Render Catch Everest Theme Options page
 *
 * @uses settings_fields, get_option, bloginfo
 * @Settings Updated
 */
function catcheverest_theme_options_do_page() {
    if (!isset($_REQUEST['settings-updated']))
        $_REQUEST['settings-updated'] = false;
    ?>

    <div id="catchthemes" class="wrap">

        <form method="post" action="options.php">
            <?php
                settings_fields( 'catcheverest_options' );
                global $catcheverest_options_settings, $catcheverest_options_defaults;
                $options    = $catcheverest_options_settings;
                $defaults   = $catcheverest_options_defaults;
            ?>
            <?php if (false !== $_REQUEST['settings-updated']) : ?>
                <div class="updated fade"><p><strong><?php _e('Options Saved', 'catch-everest-pro'); ?></strong></p></div>
            <?php endif; ?>

            <div id="theme-option-header">
                <div id="theme-option-title">
                    <h2 class="title"><?php _e( 'Theme Options By', 'catch-everest-pro' ); ?></h2>
                    <h2 class="logo">
                        <a href="<?php echo esc_url( __( 'https://catchthemes.com/', 'catch-everest-pro' ) ); ?>" title="<?php esc_attr_e( 'Catch Themes', 'catch-everest-pro' ); ?>" target="_blank">
                            <img src="<?php echo get_template_directory_uri().'/inc/panel/images/catch-themes.png'; ?>" alt="<?php _e( 'Catch Themes', 'catch-everest-pro' ); ?>" />
                        </a>
                    </h2>
                </div><!-- #theme-option-title -->

                <div id="theme-support">
                    <ul>
                        <li><a class="button" href="<?php echo esc_url(__('https://catchthemes.com/support/','catch-everest-pro')); ?>" title="<?php esc_attr_e('Support', 'catch-everest-pro'); ?>" target="_blank"><?php printf(__('Support','catch-everest-pro')); ?></a></li>
                        <li><a class="button" href="<?php echo esc_url(__('https://catchthemes.com/theme-instructions/catch-everest-pro/','catch-everest-pro')); ?>" title="<?php esc_attr_e('Theme Instruction', 'catch-everest-pro'); ?>" target="_blank"><?php printf(__('Theme Instruction','catch-everest-pro')); ?></a></li>
                        <li><a class="button" href="<?php echo esc_url(__('https://www.facebook.com/catchthemes/','catch-everest-pro')); ?>" title="<?php esc_attr_e('Like Catch Themes on Facebook', 'catch-everest-pro'); ?>" target="_blank"><?php printf(__('Facebook','catch-everest-pro')); ?></a></li>
                        <li><a class="button" href="<?php echo esc_url(__('https://twitter.com/catchthemes/','catch-everest-pro')); ?>" title="<?php esc_attr_e('Follow Catch Themes on Twitter', 'catch-everest-pro'); ?>" target="_blank"><?php printf(__('Twitter','catch-everest-pro')); ?></a></li>
                        <li><a class="button" href="<?php echo esc_url(__('http://wordpress.org/support/view/theme-reviews/catch-everest','catch-everest-pro')); ?>" title="<?php esc_attr_e('Rate us 5 Star on WordPress', 'catch-everest-pro'); ?>" target="_blank"><?php printf(__('5 Star Rating','catch-everest-pro')); ?></a></li>
                    </ul>
                </div><!-- #theme-support -->

                <div id="theme-option-header-notice">
                    <p class="notice">
                        <?php printf( _x( 'Theme Options Panel will be retired on future versions. Please use %1$s Customizer %2$s instead.','1: Customizer Link Start, 2: Customizer Link End' , 'catch-everest-pro' ) , '<a href="' . esc_url ( admin_url( 'customize.php' ) ) . '">', '</a>' ); ?>
                    </p>
                </div><!-- #theme-option-header -->

            </div><!-- #theme-option-header -->


            <div id="catcheverest_ad_tabs">
                <ul class="tabNavigation" id="mainNav">
                    <li><a href="#themeoptions"><?php _e( 'Theme Options', 'catch-everest-pro' );?></a></li>
                    <li><a href="#homepagesettings"><?php _e( 'Homepage Settings', 'catch-everest-pro' );?></a></li>
                    <li><a href="#slidersettings"><?php _e( 'Featured Slider', 'catch-everest-pro' );?></a></li>
                    <li><a href="#sociallinks"><?php _e( 'Social Links', 'catch-everest-pro' );?></a></li>
                    <li><a href="#webmaster"><?php _e( 'Webmaster Tools', 'catch-everest-pro' );?></a></li>
                </ul><!-- .tabsNavigation #mainNav -->


                <!-- Option for Design Settings -->
                <div id="themeoptions">

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Menu Options', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Disable Primary Menu?', 'catch-everest-pro' ); ?></th>
                                        <input type='hidden' value='0' name='catcheverest_options[disable_primary_menu]'>
                                        <td><input type="checkbox" id="headerlogo" name="catcheverest_options[disable_primary_menu]" value="1" <?php checked( '1', $options['disable_primary_menu'] ); ?> /> <?php _e('Check to disable', 'catch-everest-pro'); ?></td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Responsive Design', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Disable Responsive Design?', 'catch-everest-pro' ); ?></th>
                                        <input type='hidden' value='0' name='catcheverest_options[disable_responsive]'>
                                        <td><input type="checkbox" id="headerlogo" name="catcheverest_options[disable_responsive]" value="1" <?php checked( '1', $options['disable_responsive'] ); ?> /> <?php _e('Check to disable', 'catch-everest-pro'); ?></td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Enable Zoom in Mobile Devices?', 'catch-everest-pro' ); ?></th>
                                        <input type='hidden' value='0' name='catcheverest_options[enable_responsive_zoom]'>
                                        <td><input type="checkbox" id="responsive_zoom" name="catcheverest_options[enable_responsive_zoom]" value="1" <?php checked( '1', $options['enable_responsive_zoom'] ); ?> /> <?php _e('Check to disable', 'catch-everest-pro'); ?></td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Enable Footer Menu in Mobile Devices?', 'catch-everest-pro' ); ?></th>
                                        <input type='hidden' value='0' name='catcheverest_options[enable_menus]'>
                                        <td><input type="checkbox" id="headerlogo" name="catcheverest_options[enable_menus]" value="1" <?php checked( '1', $options['enable_menus'] ); ?> /> <?php _e('Check to enable', 'catch-everest-pro'); ?></td>
                                    </tr>

                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <?php
                    //@remove Remove if block when WordPress 4.8 is released
                    if( !function_exists( 'has_site_icon' ) ) {
                    ?>
                        <div class="option-container">
                            <h3 class="option-toggle"><a href="#"><?php _e( 'Favicon', 'catch-everest-pro' ); ?></a></h3>
                            <div class="option-content inside">
                                <table class="form-table">
                                    <tbody>
                                        <tr>
                                            <th scope="row"><?php _e( 'Disable Favicon?', 'catch-everest-pro' ); ?></th>
                                             <input type='hidden' value='0' name='catcheverest_options[remove_favicon]'>
                                            <td><input type="checkbox" id="favicon" name="catcheverest_options[remove_favicon]" value="1" <?php checked( '1', $options['remove_favicon'] ); ?> /> <?php _e('Check to disable', 'catch-everest-pro'); ?></td>
                                        </tr>
                                        <tr>
                                            <th scope="row"><?php _e( 'Fav Icon URL:', 'catch-everest-pro' ); ?></th>
                                            <td><?php if ( !empty ( $options['fav_icon'] ) ) { ?>
                                                    <input class="upload-url" size="65" type="text" name="catcheverest_options[fav_icon]" value="<?php echo esc_url( $options['fav_icon'] ); ?>" />
                                                <?php } else { ?>
                                                    <input class="upload-url" size="65" type="text" name="catcheverest_options[fav_icon]" value="<?php echo get_template_directory_uri(); ?>/images/favicon.ico" alt="fav" />
                                                <?php }  ?>
                                                <input ref="<?php esc_attr_e( 'Insert as Fav Icon','catch-everest-pro' );?>" class="catcheverest_upload_image button" name="wsl-image-add" type="button" value="<?php esc_attr_e( 'Change Fav Icon','catch-everest-pro' );?>" />

                                            </td>
                                        </tr>

                                        <tr>
                                            <th scope="row"><?php _e( 'Preview: ', 'catch-everest-pro' ); ?></th>
                                            <td>
                                                <?php
                                                    if ( !empty( $options['fav_icon'] ) ) {
                                                        echo '<img src="'.esc_url( $options['fav_icon'] ).'" alt="fav" />';
                                                    } else {
                                                        echo '<img src="'. get_template_directory_uri().'/images/favicon.ico" alt="fav" />';
                                                    }
                                                ?>
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                            </div><!-- .option-content -->
                        </div><!-- .option-container -->

                        <div class="option-container">
                            <h3 class="option-toggle"><a href="#"><?php _e( 'Web Clip Icon Options', 'catch-everest-pro' ); ?></a></h3>
                            <div class="option-content inside">
                                <table class="form-table">
                                    <tbody>
                                        <tr>
                                            <th scope="row"><?php _e( 'Disable Web Clip Icon?', 'catch-everest-pro' ); ?></th>
                                             <input type='hidden' value='0' name='catcheverest_options[remove_web_clip]'>
                                            <td><input type="checkbox" id="favicon" name="catcheverest_options[remove_web_clip]" value="1" <?php checked( '1', $options['remove_web_clip'] ); ?> /> <?php _e('Check to disable', 'catch-everest-pro'); ?></td>
                                        </tr>
                                        <tr>
                                            <th scope="row"><?php _e( 'Web Clip Icon URL:', 'catch-everest-pro' ); ?></th>
                                            <td><?php if ( !empty ( $options['web_clip'] ) ) { ?>
                                                    <input class="upload-url" size="65" type="text" name="catcheverest_options[web_clip]" value="<?php echo esc_url( $options['web_clip'] ); ?>" class="upload" />
                                                <?php } else { ?>
                                                    <input size="65" type="text" name="catcheverest_options[web_clip]" value="<?php echo get_template_directory_uri(); ?>/images/apple-touch-icon.png" alt="fav" />
                                                <?php }  ?>
                                                <input ref="<?php esc_attr_e( 'Insert as Web Clip Icon','catch-everest-pro' );?>" class="catcheverest_upload_image button" name="wsl-image-add" type="button" value="<?php esc_attr_e( 'Change Web Clip Icon','catch-everest-pro' );?>" />
                                            </td>
                                        </tr>

                                        <tr>
                                            <th scope="row"><?php _e( 'Preview: ', 'catch-everest-pro' ); ?></th>
                                            <td>
                                                <?php
                                                    if ( !empty( $options['web_clip'] ) ) {
                                                        echo '<img src="'.esc_url( $options['web_clip'] ).'" alt="Web Clip Icon" />';
                                                    } else {
                                                        echo '<img src="'. get_template_directory_uri().'/images/apple-touch-icon.png" alt="Web Clip Icon" />';
                                                    }
                                                ?>
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <p><?php esc_attr_e( 'Note: Web Clip Icon for Apple devices. Recommended Size - Width 144px and Height 144px height, which will support High Resolution Devices like iPad Retina.', 'catch-everest-pro' ); ?></p>
                                <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                            </div><!-- .option-content -->
                        </div><!-- .option-container -->
                    <?php
                    }
                    ?>

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Header Options', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Custom Header: Logo & Site Detais', 'catch-everest-pro' ); ?></th>
                                        <td><a class="button" href="<?php echo admin_url('themes.php?page=custom-header'); ?>"><?php _e('Click Here to Add/Replace Header Logo & Site Details', 'catch-everest-pro'); ?></a></td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Move Site Title and Description', 'catch-everest-pro' ); ?></th>
                                        <input type='hidden' value='0' name='catcheverest_options[site_title_above]'>
                                        <td><input type="checkbox" id="site-title" name="catcheverest_options[site_title_above]" value="1" <?php checked( '1', $options['site_title_above'] ); ?> /> <?php _e('Check to move above the Header/Logo Image', 'catch-everest-pro'); ?></td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Header Right Sidebar Options', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Disable Header Right Sidebar?', 'catch-everest-pro' ); ?></th>
                                        <input type='hidden' value='0' name='catcheverest_options[disable_header_right_sidebar]'>
                                        <td><input type="checkbox" id="headerlogo" name="catcheverest_options[disable_header_right_sidebar]" value="1" <?php checked( '1', $options['disable_header_right_sidebar'] ); ?> /> <?php _e('Check to Disable', 'catch-everest-pro'); ?></td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Header Right Sidebar', 'catch-everest-pro' ); ?></th>
                                        <td><a class="button" href="<?php echo esc_url( admin_url( 'widgets.php' ) ) ; ?>" title="<?php esc_attr_e( 'Widgets', 'catch-everest-pro' ); ?>"><?php _e( 'Click Here to Add/Replace Widgets', 'catch-everest-pro' );?></a></td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Header Featured Image Options', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Enable Featured Header Image', 'catch-everest-pro' ); ?></label></th>
                                        <td>
                                            <label title="enable-header-homepage" class="box">
                                            <input type="radio" name="catcheverest_options[enable_featured_header_image]" id="enable-header-homepage" <?php checked($options['enable_featured_header_image'], 'homepage'); ?> value="homepage"  />
                                            <?php _e( 'Homepage', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="enable-header-allpage" class="box">
                                            <input type="radio" name="catcheverest_options[enable_featured_header_image]" id="enable-header-allpage" <?php checked($options['enable_featured_header_image'], 'allpage'); ?> value="allpage"  />
                                             <?php _e( 'Entire Site', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="enable-header-postpage" class="box boxpostpage">
                                            <input type="radio" name="catcheverest_options[enable_featured_header_image]" id="enable-header-postpage" <?php checked($options['enable_featured_header_image'], 'postpage'); ?> value="postpage"  />
                                             <?php _e( 'Entire Site, Page/Post Featured Image', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="enable-header-pagespostes" class="box boxpostpage">
                                            <input type="radio" name="catcheverest_options[enable_featured_header_image]" id="enable-header-pagespostes" <?php checked($options['enable_featured_header_image'], 'pagespostes'); ?> value="pagespostes"  />
                                             <?php _e( 'Pages & Posts', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="disable-header" class="box">
                                            <input type="radio" name="catcheverest_options[enable_featured_header_image]" id="disable-header" <?php checked($options['enable_featured_header_image'], 'disable'); ?> value="disable" />
                                             <?php _e( 'Disable', 'catch-everest-pro' ); ?>
                                            </label>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Page/Post Featured Image Size', 'catch-everest-pro' ); ?></th>
                                        <td>
                                            <label title="featured-image" class="box"><input type="radio" name="catcheverest_options[page_featured_image]" id="image-full" <?php checked($options['page_featured_image'], 'full'); ?> value="full"  />
                                            <?php _e( 'Full Image', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="featured-image" class="box"><input type="radio" name="catcheverest_options[page_featured_image]" id="content-image-slider" <?php checked($options['page_featured_image'], 'slider'); ?> value="slider"  />
                                            <?php _e( 'Slider Image', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="featured-image" class="box"><input type="radio" name="catcheverest_options[page_featured_image]" id="image-featured" <?php checked($options['page_featured_image'], 'featured'); ?> value="featured"  />
                                            <?php _e( 'Featured Image', 'catch-everest-pro' ); ?>
                                            </label>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Featured HeaderImage Position', 'catch-everest-pro' ); ?></label></th>
                                        <td>
                                            <label title="before-menu" class="box"><input type="radio" name="catcheverest_options[featured_header_image_position]" id="before-menu" <?php checked($options['featured_header_image_position'], 'before-menu'); ?> value="before-menu"  />
                                            <?php _e( 'Before Menu', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="after-menu" class="box"><input type="radio" name="catcheverest_options[featured_header_image_position]" id="after-menu" <?php checked($options['featured_header_image_position'], 'after-menu'); ?> value="after-menu"  />
                                            <?php _e( 'After Menu', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="before-header" class="box"><input type="radio" name="catcheverest_options[featured_header_image_position]" id="before-header" <?php checked($options['featured_header_image_position'], 'before-header'); ?> value="before-header"  />
                                            <?php _e( 'Before Header', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="after-sidebartop" class="box"><input type="radio" name="catcheverest_options[featured_header_image_position]" id="after-sidebartop" <?php checked($options['featured_header_image_position'], 'after-sidebartop'); ?> value="after-sidebartop"  />
                                            <?php _e( 'After Top Sidebar', 'catch-everest-pro' ); ?>
                                            </label>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Featured Header Image URL', 'catch-everest-pro' ); ?></th>
                                        <td>
                                            <input class="upload-url" size="65" type="text" name="catcheverest_options[featured_header_image]" value="<?php echo esc_url( $options['featured_header_image'] ); ?>" /> <input ref="<?php esc_attr_e( 'Insert as Featured Header Image','catch-everest-pro' );?>" class="catcheverest_upload_image button" name="wsl-image-add" type="button" value="<?php esc_attr_e( 'Change Image','catch-everest-pro' );?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Featured Header Image Alt/Title Tag', 'catch-everest-pro' ); ?></th>
                                        <td>
                                            <input class="upload-url" size="65" type="text" name="catcheverest_options[featured_header_image_alt]" value="<?php echo esc_attr( $options['featured_header_image_alt'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Featured Header Image Link URL', 'catch-everest-pro' ); ?></label></th>
                                        <td><input type="text" size="65" name="catcheverest_options[featured_header_image_url]" value="<?php echo esc_url( $options['featured_header_image_url'] ); ?>" /> <?php _e( 'Add in the Link URL', 'catch-everest-pro' ); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Target. Open Link in New Window?', 'catch-everest-pro' ); ?></label></th>
                                        <input type="hidden" value="0" name="catcheverest_options[featured_header_image_base]">
                                        <td><input type="checkbox" id="header-image-base" name="catcheverest_options[featured_header_image_base]" value="1" <?php checked( '1', $options['featured_header_image_base'] ); ?> /> <?php _e('Check to open in new window', 'catch-everest-pro'); ?>
                                        </td>
                                    </tr>

                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Content Featured Image Options', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Content Featured Image Size', 'catch-everest-pro' ); ?></th>
                                        <td>
                                            <label title="featured-image" class="box"><input type="radio" name="catcheverest_options[featured_image]" id="image-featured" <?php checked($options['featured_image'], 'featured'); ?> value="featured"  />
                                            <?php _e( 'Featured Image', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="featured-image" class="box"><input type="radio" name="catcheverest_options[featured_image]" id="image-full" <?php checked($options['featured_image'], 'full'); ?> value="full"  />
                                            <?php _e( 'Full Image', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="featured-image" class="box"><input type="radio" name="catcheverest_options[featured_image]" id="content-image-slider" <?php checked($options['featured_image'], 'slider'); ?> value="slider"  />
                                            <?php _e( 'Slider Image', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="featured-image" class="box"><input type="radio" name="catcheverest_options[featured_image]" id="disable-image-slider" <?php checked($options['featured_image'], 'disable'); ?> value="disable"  />
                                            <?php _e( 'Disable Image', 'catch-everest-pro' ); ?>
                                            </label>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Layout Options', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table content-layout">
                                <tbody>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Sidebar Layout Options', 'catch-everest-pro' ); ?></label></th>
                                        <td>
                                            <label title="right-sidebar" class="box"><img src="<?php echo get_template_directory_uri(); ?>/inc/panel/images/right-sidebar.png" alt="Right Sidebar" /><br />
                                            <input type="radio" name="catcheverest_options[sidebar_layout]" id="right-sidebar" <?php checked($options['sidebar_layout'], 'right-sidebar'); ?> value="right-sidebar"  />
                                            <?php _e( 'Right Sidebar', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="left-Sidebar" class="box"><img src="<?php echo get_template_directory_uri(); ?>/inc/panel/images/left-sidebar.png" alt="Left Sidebar" /><br />
                                            <input type="radio" name="catcheverest_options[sidebar_layout]" id="left-sidebar" <?php checked($options['sidebar_layout'], 'left-sidebar'); ?> value="left-sidebar"  />
                                            <?php _e( 'Left Sidebar', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="no-sidebar" class="box"><img src="<?php echo get_template_directory_uri(); ?>/inc/panel/images/no-sidebar.png" alt="No Sidebar" /><br />
                                            <input type="radio" name="catcheverest_options[sidebar_layout]" id="no-sidebar" <?php checked($options['sidebar_layout'], 'no-sidebar'); ?> value="no-sidebar"  />
                                            <?php _e( 'No Sidebar', 'catch-everest-pro' ); ?>
                                            </label>


                                            <label title="no-sidebar-full-width" class="box"><img src="<?php echo get_template_directory_uri(); ?>/inc/panel/images/no-sidebar-fullwidth.png" alt="No Sidebar, Full Width" /><br />
                                            <input type="radio" name="catcheverest_options[sidebar_layout]" id="no-sidebar-full-width" <?php checked($options['sidebar_layout'], 'no-sidebar-full-width'); ?> value="no-sidebar-full-width"  />
                                            <?php _e( 'No Sidebar, Full Width', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="no-sidebar-one-column" class="box"><img src="<?php echo get_template_directory_uri(); ?>/inc/panel/images/one-column.png" alt="No Sidebar, One Column" /><br />
                                            <input type="radio" name="catcheverest_options[sidebar_layout]" id="no-sidebar-one-column" <?php checked($options['sidebar_layout'], 'no-sidebar-one-column'); ?> value="no-sidebar-one-column"  />
                                            <?php _e( 'No Sidebar, One Column', 'catch-everest-pro' ); ?>
                                            </label>

                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Content Layout', 'catch-everest-pro' ); ?></label></th>
                                        <td>
                                            <label title="content-full" class="box"><input type="radio" name="catcheverest_options[content_layout]" id="content-full" <?php checked($options['content_layout'], 'full'); ?> value="full"  />
                                            <?php _e( 'Full Content Display', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="content-excerpt" class="box"><input type="radio" name="catcheverest_options[content_layout]" id="content-excerpt" <?php checked($options['content_layout'], 'excerpt'); ?> value="excerpt"  />
                                            <?php _e( 'Excerpt/Blog Display', 'catch-everest-pro' ); ?>
                                            </label>
                                        </td>
                                    </tr>
                                    <?php if( $options['reset_layout'] == "1" ) { $options['reset_layout'] = "0"; } ?>
                                    <tr>
                                        <th scope="row"><?php _e( 'Reset Layout?', 'catch-everest-pro' ); ?></th>
                                        <input type='hidden' value='0' name='catcheverest_options[reset_layout]'>
                                        <td>
                                            <input type="checkbox" id="headerlogo" name="catcheverest_options[reset_layout]" value="1" <?php checked( '1', $options['reset_layout'] ); ?> /> <?php _e('Check to reset', 'catch-everest-pro'); ?>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Color Options', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Default Color Scheme', 'catch-everest-pro' ); ?></label></th>
                                        <td>
                                            <label title="color-light" class="box"><img src="<?php echo get_template_directory_uri(); ?>/inc/panel/images/light.png" alt="color-light" /><br />
                                            <input type="radio" name="catcheverest_options[color_scheme]" id="color-light" <?php checked($options['color_scheme'], 'light'); ?> value="light"  />
                                            <?php _e( 'Light', 'catch-everest-pro' ); ?>
                                            </label>
                                            <label title="color-dark" class="box"><img src="<?php echo get_template_directory_uri(); ?>/inc/panel/images/dark.png" alt="color-dark" /><br />
                                            <input type="radio" name="catcheverest_options[color_scheme]" id="color-dark" <?php checked($options['color_scheme'], 'dark'); ?> value="dark"  />
                                            <?php _e( 'Dark', 'catch-everest-pro' ); ?>
                                            </label>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catcheverest_custom_background">
                                                <?php _e( 'Custom Background Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <a class="button" href="<?php echo admin_url('themes.php?page=custom-background'); ?>">
                                                <?php _e( 'Click Here to change Background Color/Image', 'catch-everest-pro' ); ?>
                                            </a>
                                        </td>
                                    </tr>

                                    <tr>
                                        <th>
                                            <label for="catcheverest_header_background">
                                                <?php _e( 'Header Background Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[header_background]" size="8" value="<?php echo ( isset( $options['header_background'] ) ) ? esc_attr( $options['header_background'] ) : '#fff'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'header_background' ] ); ?>" />
                                        </td>
                                    </tr>

                                    <tr>
                                        <th>
                                            <label for="catcheverest_content_background">
                                                <?php _e( 'Content Background Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[content_background]" size="8" value="<?php echo ( isset( $options['content_background'] ) ) ? esc_attr( $options['content_background'] ) : '#fff'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'content_background' ] ); ?>" />
                                        </td>
                                    </tr>

                                    <tr>
                                        <th>
                                            <label for="catcheverest_footer_sidebar_background">
                                                <?php _e( 'Footer Background Sidebar Color: ', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[footer_sidebar_background]" size="8" value="<?php echo ( isset( $options['footer_sidebar_background'] ) ) ? esc_attr( $options['footer_sidebar_background'] ) : '#fafafa'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'footer_sidebar_background' ] ); ?>" />
                                        </td>
                                    </tr>

                                    <tr>
                                        <th>
                                            <label for="catcheverest_footer_background">
                                                <?php _e( 'Footer Background Color: ', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[footer_background]" size="8" value="<?php echo ( isset( $options['footer_background'] ) ) ? esc_attr( $options['footer_background'] ) : '#3a3d41'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'footer_background' ] ); ?>" />
                                        </td>
                                    </tr>

                                    <tr>
                                        <th>
                                            <label for="catcheverest_custom_background">
                                                <?php _e( 'Custom Header: ', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <a class="button" href="<?php echo admin_url('themes.php?page=custom-header'); ?>">
                                                <?php _e( 'Click Here to change Site Title and Tagline Color', 'catch-everest-pro' ); ?>
                                            </a>
                                        </td>
                                    </tr>


                                    <tr>
                                        <th>
                                            <label for="catcheverest_title">
                                                <?php _e( 'Title Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[title_color]" size="8" value="<?php echo ( isset( $options['title_color'] ) ) ? esc_attr( $options['title_color'] ) : '#333'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'title_color' ] ); ?>" />
                                        </td>
                                    </tr>

                                     <tr>
                                        <th>
                                            <label for="catcheverest_title_hover">
                                                <?php _e( 'Title Hover Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[title_hover_color]" size="8" value="<?php echo ( isset( $options['title_hover_color'] ) ) ? esc_attr( $options['title_hover_color'] ) : '#0088cc'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'title_hover_color' ] ); ?>" />
                                        </td>
                                    </tr>

                                    <tr>
                                        <th>
                                            <label for="catcheverest_meta_color">
                                                <?php _e( 'Meta Description Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[meta_color]" size="8" value="<?php echo ( isset( $options['meta_color'] ) ) ? esc_attr( $options['meta_color'] ) : '#757575'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'meta_color' ] ); ?>" />
                                        </td>
                                    </tr>


                                    <tr>
                                        <th>
                                            <label for="catcheverest_text_color">
                                                <?php _e( 'Text Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[text_color]" size="8" value="<?php echo ( isset( $options['text_color'] ) ) ? esc_attr( $options['text_color'] ) : '#404040'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'text_color' ] ); ?>" />
                                        </td>
                                    </tr>

                                    <tr>
                                        <th>
                                            <label for="catcheverest_link_color">
                                                <?php _e( 'Link Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[link_color]" size="8" value="<?php echo ( isset( $options['link_color'] ) ) ? esc_attr( $options['link_color'] ) : '#404040'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'link_color' ] ); ?>" />
                                        </td>
                                    </tr>

                                    <tr>
                                        <th>
                                            <label for="catcheverest_widget_title_color">
                                                <?php _e( 'Sidebar Widget Title Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[widget_title_color]" size="8" value="<?php echo ( isset( $options['widget_title_color'] ) ) ? esc_attr( $options['widget_title_color'] ) : '#404040'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'widget_title_color' ] ); ?>" />
                                        </td>
                                    </tr>

                                    <tr>
                                        <th>
                                            <label for="catcheverest_widget_color">
                                                <?php _e( 'Sidebar Widget Text Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[widget_color]" size="8" value="<?php echo ( isset( $options['widget_color'] ) ) ? esc_attr( $options['widget_color'] ) : '#404040'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'widget_color' ] ); ?>" />
                                        </td>
                                    </tr>

                                    <tr>
                                        <th>
                                            <label for="catcheverest_widget_link_color">
                                                <?php _e( 'Sidebar Widget Link Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[widget_link_color]" size="8" value="<?php echo ( isset( $options['widget_link_color'] ) ) ? esc_attr( $options['widget_link_color'] ) : '#757575'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'widget_link_color' ] ); ?>" />
                                        </td>
                                    </tr>

                                    <tr>
                                        <th>
                                            <label for="catcheverest_home_headline_background">
                                                <?php _e( 'Homepage Headline Background Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[home_headline_background]" size="8" value="<?php echo ( isset( $options['home_headline_background'] ) ) ? esc_attr( $options['home_headline_background'] ) : '#fafafa'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'home_headline_background' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catcheverest_home_headline">
                                                <?php _e( 'Homepage Headline Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[home_headline]" size="8" value="<?php echo ( isset( $options['home_headline'] ) ) ? esc_attr( $options['home_headline'] ) : '#404040'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'home_headline' ] ); ?>" />
                                        </td>
                                    </tr>


                                    <tr>
                                        <th>
                                            <label for="catcheverest_menu_background">
                                                <?php _e( 'Menu Background Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker"  name="catcheverest_options[menu_background]" size="8" value="<?php echo ( isset( $options['menu_background'] ) ) ? esc_attr( $options['menu_background'] ) : '#3a3d41'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'menu_background' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catcheverest_menu_color">
                                                <?php _e( 'Menu Text Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[menu_color]" size="8" value="<?php echo ( isset( $options['menu_color'] ) ) ? esc_attr( $options['menu_color'] ) : '#eee'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'menu_color' ] ); ?>" />
                                        </td>
                                    </tr>

                                    <tr>
                                        <th>
                                            <label for="catcheverest_hover_active_color">
                                                <?php _e( 'Menu Hover & Active Background Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[hover_active_color]" size="8" value="<?php echo ( isset( $options['hover_active_color'] ) ) ? esc_attr( $options['hover_active_color'] ) : '#000'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'hover_active_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catcheverest_hover_active_text_color">
                                                <?php _e( 'Menu Hover & Active Text Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[hover_active_text_color]" size="8" value="<?php echo ( isset( $options['hover_active_text_color'] ) ) ? esc_attr( $options['hover_active_text_color'] ) : '#eee'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'hover_active_text_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catcheverest_scrollup_bg_color">
                                                <?php _e( 'Sub-Menu Background Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[sub_menu_bg_color]" size="8" value="<?php echo ( isset( $options['sub_menu_bg_color'] ) ) ? esc_attr( $options['sub_menu_bg_color'] ) : '#222'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'sub_menu_bg_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catcheverest_sub_menu_text_color">
                                                <?php _e( 'Sub-Menu Text Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[sub_menu_text_color]" size="8" value="<?php echo ( isset( $options['sub_menu_text_color'] ) ) ? esc_attr( $options['sub_menu_text_color'] ) : '#fff'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'sub_menu_text_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catcheverest_sub_menu_bg_color">
                                                <?php _e( 'Scroll Up Background Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[scrollup_bg_color]" size="8" value="<?php echo ( isset( $options['scrollup_bg_color'] ) ) ? esc_attr( $options['scrollup_bg_color'] ) : '#000'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'scrollup_bg_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catcheverest_scrollup_text_color">
                                                <?php _e( 'Scroll Up Text Color:', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catcheverest_color_picker" name="catcheverest_options[scrollup_text_color]" size="8" value="<?php echo ( isset( $options['scrollup_text_color'] ) ) ? esc_attr( $options['scrollup_text_color'] ) : '#fff'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'scrollup_text_color' ] ); ?>" />
                                        </td>
                                    </tr>

                                    <?php if( $options['reset_color'] == "1" ) { $options['reset_color'] = "0"; } ?>
                                    <tr>
                                        <th scope="row"><?php _e( 'Reset Color?', 'catch-everest-pro' ); ?></th>
                                        <input type='hidden' value='0' name='catcheverest_options[reset_color]'>
                                        <td>
                                            <input type="checkbox" id="headerlogo" name="catcheverest_options[reset_color]" value="1" <?php checked( '1', $options['reset_color'] ); ?> /> <?php _e('Check to reset', 'catch-everest-pro'); ?>
                                        </td>
                                    </tr>
                              </tbody>
                            </table>
                          <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->


                    <?php
                    /**
                      * Renders the Font Family Option.
                      *
                      * @since Simple Catch Pro 1.0
                      */

                      //Getting Font Available
                      $fonts = catcheverest_available_fonts();

                    ?>
                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Font Family Options', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th>
                                            <label for="catcheverest_default_font_family">
                                                <?php _e( 'Default Font Family', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <select name="catcheverest_options[body_font]">
                                                <?php foreach( $fonts as $name => $family ) : ?>
                                                    <option value="<?php echo $name; ?>" <?php selected( $name, $options['body_font'] ); ?>><?php echo str_replace( '"', '', $family ); ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catcheverest_title_font_family">
                                                <?php _e( 'Site Title Font Family', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <select name="catcheverest_options[title_font]">
                                                <?php foreach( $fonts as $name => $family ) : ?>
                                                    <option value="<?php echo $name; ?>" <?php selected( $name, $options['title_font'] ); ?>><?php echo str_replace( '"', '', $family ); ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>

                                    <tr>
                                        <th>
                                            <label for="catcheverest_tagline_font_family">
                                                <?php _e( 'Site Tagline Font Family', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <select name="catcheverest_options[tagline_font]">
                                                <?php foreach( $fonts as $name => $family ) : ?>
                                                    <option value="<?php echo $name; ?>" <?php selected( $name, $options['tagline_font'] ); ?>><?php echo str_replace( '"', '', $family ); ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>

                                    <tr>
                                        <th>
                                            <label for="catcheverest_content_tittle_font_family">
                                                <?php _e( 'Content Title Font Family', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <select name="catcheverest_options[content_tittle_font]">
                                                <?php foreach( $fonts as $name => $family ) : ?>
                                                    <option value="<?php echo $name; ?>" <?php selected( $name, $options['content_tittle_font'] ); ?>><?php echo str_replace( '"', '', $family ); ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catcheverest_content_font_family">
                                                <?php _e( 'Content Body Font Family', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <select name="catcheverest_options[content_font]">
                                                <?php foreach( $fonts as $name => $family ) : ?>
                                                    <option value="<?php echo $name; ?>" <?php selected( $name, $options['content_font'] ); ?>><?php echo str_replace( '"', '', $family ); ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catcheverest_headings_font_family">
                                                <?php _e( 'Headings Tags from h1 to h6 Font Family', 'catch-everest-pro' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <select name="catcheverest_options[headings_font]">
                                                <?php foreach( $fonts as $name => $family ) : ?>
                                                    <option value="<?php echo $name; ?>" <?php selected( $name, $options['headings_font'] ); ?>><?php echo str_replace( '"', '', $family ); ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>

                                    <?php if( $options['reset_typography'] == "1" ) { $options['reset_typography'] = "0"; } ?>
                                    <tr>
                                        <th scope="row"><?php _e( 'Reset Fonts?', 'catch-everest-pro' ); ?></th>
                                            <input type='hidden' value='0' name='catcheverest_options[reset_typography]'>
                                            <td><input type="checkbox" id="reset_family" name="catcheverest_options[reset_typography]" value="1" <?php checked( '1', $options['reset_typography'] ); ?> /> <?php _e('Check to reset', 'catch-everest-pro'); ?></td>
                                    </tr>
                                <tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Search Text Settings', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Default Display Text in Search', 'catch-everest-pro' ); ?></label></th>
                                        <td><input type="text" size="45" name="catcheverest_options[search_display_text]" value="<?php echo esc_attr( $options[ 'search_display_text'] ); ?>" />
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Excerpt / More Tag Settings', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'More Tag Text', 'catch-everest-pro' ); ?></label></th>
                                        <td><input type="text" size="45" name="catcheverest_options[more_tag_text]" value="<?php echo esc_attr( $options['more_tag_text'] ); ?>" />
                                        </td>
                                    </tr>
                                     <tr>
                                        <th scope="row"><?php _e( 'Excerpt length(words)', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="3" name="catcheverest_options[excerpt_length]" value="<?php echo intval( $options['excerpt_length'] ); ?>" /></td>
                                    </tr>
                                    <?php if( $options['reset_moretag'] == "1" ) { $options['reset_moretag'] = "0"; } ?>
                                    <tr>
                                        <th scope="row"><?php _e( 'Reset Excerpt?', 'catch-everest-pro' ); ?></th>
                                        <input type='hidden' value='0' name='catcheverest_options[reset_moretag]'>
                                        <td>
                                            <input type="checkbox" id="headerlogo" name="catcheverest_options[reset_moretag]" value="1" <?php checked( '1', $options['reset_moretag'] ); ?> /> <?php _e('Check to reset', 'catch-everest-pro'); ?>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Feed Redirect', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Feed Redirect URL', 'catch-everest-pro' ); ?></label></th>
                                        <td><input type="text" size="70" name="catcheverest_options[feed_url]" value="<?php echo esc_attr( $options['feed_url'] ); ?>" /> <?php _e( 'Add in the Feedburner URL', 'catch-everest-pro' ); ?>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Comments Options', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table comment-settings">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Commenting', 'catch-everest-pro' ); ?></th>
                                        <td>
                                            <label title="commenting-setting" class="box"><input type="radio" name="catcheverest_options[commenting_setting]" id="default" <?php checked($options['commenting_setting'], 'default'); ?> value="default"  />
                                            <?php _e( 'Use WordPress Settings', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="commenting-setting" class="box"><input type="radio" name="catcheverest_options[commenting_setting]" id="page" <?php checked($options['commenting_setting'], 'page'); ?> value="page"  />
                                            <?php _e( 'Disabled for Pages', 'catch-everest-pro' ); ?>
                                            </label>

                                            <label title="commenting-setting" class="box"><input type="radio" name="catcheverest_options[commenting_setting]" id="disable" <?php checked($options['commenting_setting'], 'disable'); ?> value="disable"  />
                                            <?php _e( 'Disabled Completely', 'catch-everest-pro' ); ?>
                                            </label>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Footer Editor Option', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tr>
                                    <th scope="row">
                                        <label for="footer-editor"><?php _e( 'Footer Editor', 'catch-everest-pro' ); ?></label>
                                         <p>
                                            <small><?php _e( 'You can add custom <acronym title="Hypertext Markup Language">HTML</acronym> and/or codes, which will be automatically inserted into your theme.<br />Some codes: [the-year], [site-link], [wp-link] for current year, your site link, wordpress site link respectively.', 'catch-everest-pro' ); ?></small>
                                        </p>
                                    </th>
                                    <td>
                                        <?php
                                        $settings = array(
                                                'wpautop'               => false,
                                                'media_buttons'         => false,  // Don't show upload botton
                                                'textarea_name'         => 'catcheverest_options[footer_code]',
                                                'tinymce'               => false,  // Don't use TinyMCE in a meta box.
                                                'textarea_rows'         => 3
                                            );
                                        wp_editor( esc_textarea( $options['footer_code'] ), 'catcheverest_options_footer_code', $settings ); ?>
                                    </td>
                                </tr>
                                <?php if( $options['reset_footer'] == "1" ) { $options['reset_footer'] = "0"; } ?>
                                <tr>
                                    <th scope="row"><?php _e( 'Reset Footer?', 'catch-everest-pro' ); ?></th>
                                    <input type='hidden' value='0' name='catcheverest_options[reset_footer]'>
                                    <td>
                                        <input type="checkbox" id="headerlogo" name="catcheverest_options[reset_footer]" value="1" <?php checked( '1', $options['reset_footer'] ); ?> /> <?php _e('Check to reset', 'catch-everest-pro'); ?>
                                    </td>
                                </tr>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <?php
                    // @remove if block when WP 5.0 is released
                    if ( ! function_exists( 'wp_update_custom_css_post' ) ) {
                    ?>
                        <div class="option-container">
                            <h3 class="option-toggle"><a href="#"><?php _e( 'Custom CSS', 'catch-everest-pro' ); ?></a></h3>
                            <div class="option-content inside">
                                <table class="form-table">
                                    <tbody>
                                        <tr>
                                            <th scope="row"><?php _e( 'Enter your custom CSS styles.', 'catch-everest-pro' ); ?></th>
                                            <td>
                                                <textarea name="catcheverest_options[custom_css]" id="custom-css" cols="90" rows="12"><?php echo esc_attr( $options['custom_css'] ); ?></textarea>
                                            </td>
                                        </tr>

                                        <tr>
                                            <th scope="row"><?php _e( 'CSS Tutorial from W3Schools.', 'catch-everest-pro' ); ?></th>
                                            <td>
                                                <a class="button" href="<?php echo esc_url( __( 'http://www.w3schools.com/css/default.asp','catch-everest-pro' ) ); ?>" title="<?php esc_attr_e( 'CSS Tutorial', 'catch-everest-pro' ); ?>" target="_blank"><?php _e( 'Click Here to Read', 'catch-everest-pro' );?></a>
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-everest-pro' ); ?>" /></p>
                            </div><!-- .option-content -->
                        </div><!-- .option-container -->
                    <?php
                    }
                    ?>

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Scroll Up', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Disable Scroll Up?', 'catch-everest-pro' ); ?></th>
                                        <input type='hidden' value='0' name='catcheverest_options[disable_scrollup]'>
                                        <td><input type="checkbox" id="headerlogo" name="catcheverest_options[disable_scrollup]" value="1" <?php checked( '1', $options['disable_scrollup'] ); ?> /> <?php _e('Check to disable', 'catch-everest-pro'); ?></td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Update Notifier', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Disable Update Notifier?', 'catch-everest-pro' ); ?></th>
                                        <input type='hidden' value='0' name='catcheverest_options[disable_notifier]'>
                                        <td><input type="checkbox" id="headerlogo" name="catcheverest_options[disable_notifier]" value="1" <?php checked( '1', $options['disable_notifier'] ); ?> /> <?php _e('Check to disable', 'catch-everest-pro'); ?></td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                </div><!-- #themeoptions -->

                <!-- Options for Homepage Settings -->
                <div id="homepagesettings">

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Homepage Headline Options', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Homepage Headline', 'catch-everest-pro' ); ?>
                                            <p><small><?php _e( 'The appropriate length for Headine is around 10 words.', 'catch-everest-pro' ); ?></small></p>
                                        </th>
                                        <td>
                                            <textarea class="textarea input-bg" name="catcheverest_options[homepage_headline]" cols="65" rows="3"><?php echo esc_textarea( $options['homepage_headline'] ); ?></textarea>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Homepage Subheadline Headline', 'catch-everest-pro' ); ?>
                                            <p><small><?php _e( 'The appropriate length for Headine is around 10 words.', 'catch-everest-pro' ); ?></small></p>
                                        </th>
                                        <td>
                                            <textarea class="textarea input-bg" name="catcheverest_options[homepage_subheadline]" cols="65" rows="3"><?php echo esc_textarea( $options['homepage_subheadline'] ); ?></textarea>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Disable Homepage Headline?', 'catch-everest-pro' ); ?></th>
                                        <input type='hidden' value='0' name='catcheverest_options[disable_homepage_headline]'>
                                        <td><input type="checkbox" id="favicon" name="catcheverest_options[disable_homepage_headline]" value="1" <?php checked( '1', $options['disable_homepage_headline'] ); ?> /> <?php _e( 'Check to disable', 'catch-everest-pro'); ?></td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Disable Homepage Subheadline?', 'catch-everest-pro' ); ?></th>
                                        <input type='hidden' value='0' name='catcheverest_options[disable_homepage_subheadline]'>
                                        <td><input type="checkbox" id="favicon" name="catcheverest_options[disable_homepage_subheadline]" value="1" <?php checked( '1', $options['disable_homepage_subheadline'] ); ?> /> <?php _e( 'Check to disable', 'catch-everest-pro'); ?></td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Homepage Featured Content Options', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Disable Homepage Featured Content?', 'catch-everest-pro' ); ?></th>
                                        <input type='hidden' value='0' name='catcheverest_options[disable_homepage_featured]'>
                                        <td><input type="checkbox" id="favicon" name="catcheverest_options[disable_homepage_featured]" value="1" <?php checked( '1', $options['disable_homepage_featured'] ); ?> /> <?php _e( 'Check to disable', 'catch-everest-pro'); ?></td>
                                    </tr>
                                    <tr>
                                        <th scope="row">
                                            <?php _e( 'Headline', 'catch-everest-pro' ); ?>
                                        </th>
                                        <td>
                                            <input type="text" size="65" name="catcheverest_options[homepage_featured_headline]" value="<?php echo esc_attr( $options['homepage_featured_headline'] ); ?>" /> <?php _e( 'Leave empty if you want to remove headline', 'catch-everest-pro' ); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Number of Featured Content', 'catch-everest-pro' ); ?></th>
                                        <td>
                                            <input type="text" size="2" name="catcheverest_options[homepage_featured_qty]" value="<?php echo intval( $options['homepage_featured_qty'] ); ?>" size="2" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Featured Content Layout', 'catch-everest-pro' ); ?></th>
                                        <td>
                                        <label title="three-columns" class="box">
                                        <input type="radio" name="catcheverest_options[homepage_featured_layout]" id="three-columns" <?php checked($options['homepage_featured_layout'], 'three-columns'); ?> value="three-columns"  />
                                        <?php _e( '3 Columns', 'catch-everest-pro' ); ?>
                                        </label>

                                        <label title="four-columns" class="box">
                                        <input type="radio" name="catcheverest_options[homepage_featured_layout]" id="four-columns" <?php checked($options['homepage_featured_layout'], 'four-columns'); ?> value="four-columns"  />
                                        <?php _e( '4 Columns', 'catch-everest-pro' ); ?>
                                        </label>
                                        </td>
                                    </tr>
                                    <?php for ( $i = 1; $i <= $options['homepage_featured_qty']; $i++ ): ?>
                                    <tr style="border-top: 1px solid #ddd;">
                                        <th scope="row">
                                            <strong><?php printf( esc_attr__( 'Featured Content #%s', 'catch-everest-pro' ), $i ); ?></strong>
                                        </th>
                                    </tr>
                                    <tr>
                                        <th scope="row">
                                            <?php _e( 'Image', 'catch-everest-pro' ); ?>
                                        </th>
                                        <td>
                                            <input class="upload-url" size="65" type="text" name="catcheverest_options[homepage_featured_image][<?php echo $i; ?>]" value="<?php if( array_key_exists( 'homepage_featured_image', $options ) && array_key_exists( $i, $options['homepage_featured_image'] ) ) echo esc_url( $options['homepage_featured_image'][ $i ] ); ?>" />
                                            <input ref="<?php printf( esc_attr__( 'Insert as Featured Content #%s', 'catch-everest-pro' ), $i ); ?>" class="catcheverest_upload_image button" name="wsl-image-add" type="button" value="<?php if( array_key_exists( 'homepage_featured_image', $options ) && array_key_exists( $i, $options['homepage_featured_image'] ) ) { esc_attr_e( 'Change Image','catch-everest-pro' ); } else { esc_attr_e( 'Add Image','catch-everest-pro' ); } ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Link URL', 'catch-everest-pro' ); ?></label></th>
                                        <td><input type="text" size="65" name="catcheverest_options[homepage_featured_url][<?php echo absint( $i ); ?>]" value="<?php if( array_key_exists( 'homepage_featured_url', $options ) && array_key_exists( $i, $options['homepage_featured_url'] ) ) echo esc_url( $options['homepage_featured_url'][ $i ] ); ?>" /> <?php _e( 'Add in the Target URL for the content', 'catch-everest-pro' ); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Target. Open Link in New Window?', 'catch-everest-pro' ); ?></label></th>
                                        <input type='hidden' value='0' name='catcheverest_options[homepage_featured_base][<?php echo absint( $i ); ?>]'>
                                        <td><input type="checkbox" name="catcheverest_options[homepage_featured_base][<?php echo absint( $i ); ?>]" value="1" <?php if( array_key_exists( 'homepage_featured_base', $options ) && array_key_exists( $i, $options['homepage_featured_base'] ) ) checked( '1', $options['homepage_featured_base'][ $i ] ); ?> /> <?php _e( 'Check to open in new window', 'catch-everest-pro' ); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row">
                                            <?php _e( 'Title', 'catch-everest-pro' ); ?>
                                        </th>
                                        <td>
                                            <input type="text" size="65" name="catcheverest_options[homepage_featured_title][<?php echo absint( $i ); ?>]" value="<?php if( array_key_exists( 'homepage_featured_title', $options ) && array_key_exists( $i, $options['homepage_featured_title'] ) ) echo esc_attr( $options['homepage_featured_title'][ $i ] ); ?>" /> <?php _e( 'Leave empty if you want to remove title', 'catch-everest-pro' ); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Content', 'catch-everest-pro' ); ?>
                                            <p><small><?php _e( 'The appropriate length for Content is around 10 words.', 'catch-everest-pro' ); ?></small></p>
                                        </th>
                                        <td>
                                            <textarea class="textarea input-bg" name="catcheverest_options[homepage_featured_content][<?php echo absint( $i ); ?>]" cols="80" rows="3"><?php if( array_key_exists( 'homepage_featured_content', $options ) && array_key_exists( $i, $options['homepage_featured_content'] ) ) echo esc_html( $options['homepage_featured_content'][ $i ] ); ?></textarea>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Author', 'catch-everest-pro' ); ?></th>
                                        <td>
                                        <?php
                                            if( array_key_exists( 'homepage_featured_author', $options ) && array_key_exists( $i, $options['homepage_featured_author'] ) ) {
                                                $author =  $options['homepage_featured_author'][ $i ];
                                            }
                                            else {
                                                $author = 0;
                                            }

                                            wp_dropdown_users( array(
                                                        'name'              => 'catcheverest_options[homepage_featured_author][' . absint( $i ) . ']',
                                                        'selected'          => absint( $author ),
                                                        'orderby'           => 'ID',
                                                        )
                                                    );
                                        ?>
                                        </td>
                                    </tr>
                                    <?php endfor; ?>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Homepage / Frontpage Settings', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Enable Latest Posts or Page?', 'catch-everest-pro' ); ?></th>
                                        <input type='hidden' value='0' name='catcheverest_options[enable_posts_home]'>
                                        <td><input type="checkbox" id="headerlogo" name="catcheverest_options[enable_posts_home]" value="1" <?php checked( '1', $options['enable_posts_home'] ); ?> /> <?php _e( 'Check to Enable', 'catch-everest-pro'); ?></td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Add Page instead of Latest Posts', 'catch-everest-pro' ); ?></th>
                                        <td><a class="button" href="<?php echo esc_url( admin_url( 'options-reading.php' ) ) ; ?>" title="<?php esc_attr_e( 'Click Here to Set Static Front Page Instead of Latest Posts', 'catch-everest-pro' ); ?>" target="_blank"><?php _e( 'Click Here to Set Static Front Page Instead of Latest Posts', 'catch-everest-pro' );?></a></td>
                                    </tr>
                                    <tr>
                                        <th scope="row">
                                            <?php _e( 'Homepage posts categories:', 'catch-everest-pro' ); ?>
                                            <p>
                                                <small><?php _e( 'Only posts that belong to the categories selected here will be displayed on the front page.', 'catch-everest-pro' ); ?></small>
                                            </p>
                                        </th>
                                        <td>
                                            <select name="catcheverest_options[front_page_category][]" id="frontpage_posts_cats" multiple="multiple" class="select-multiple">
                                                <option value="0" <?php if ( empty( $options['front_page_category'] ) ) { echo 'selected="selected"'; } ?>><?php _e( '--Disabled--', 'catch-everest-pro' ); ?></option>
                                                <?php /* Get the list of categories */
                                                    $categories = get_categories();
                                                    if( empty( $options['front_page_category'] ) ) {
                                                        $options['front_page_category'] = array();
                                                    }
                                                    foreach ( $categories as $category) :
                                                ?>
                                                <option value="<?php echo $category->cat_ID; ?>" <?php if ( in_array( $category->cat_ID, $options['front_page_category'] ) ) {echo 'selected="selected"';}?>><?php echo $category->cat_name; ?></option>
                                                <?php endforeach; ?>
                                            </select><br />
                                            <span class="description"><?php _e( 'You may select multiple categories by holding down the CTRL key.', 'catch-everest-pro' ); ?></span>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Move above Homepage Featured Content?', 'catch-everest-pro' ); ?></th>
                                        <input type='hidden' value='0' name='catcheverest_options[move_posts_home]'>
                                        <td><input type="checkbox" id="headerlogo" name="catcheverest_options[move_posts_home]" value="1" <?php checked( '1', $options['move_posts_home'] ); ?> /> <?php _e( 'Check to Move', 'catch-everest-pro'); ?></td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                </div><!-- #homepagesettings -->

                <!-- Options for Slider Settings -->
                <div id="slidersettings">
                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Slider Options', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tr>
                                    <th scope="row"><label><?php _e( 'Select Slider Type', 'catch-everest-pro' ); ?></label></th>
                                    <td>
                                        <label title="demo-slider" class="box">
                                        <input type="radio" name="catcheverest_options[select_slider_type]" id="demo-slider" <?php checked($options['select_slider_type'], 'demo-slider'); ?> value="demo-slider"  />
                                        <?php _e( 'Demo Slider', 'catch-everest-pro' ); ?>
                                        </label>

                                        <label title="post-slider" class="box">
                                        <input type="radio" name="catcheverest_options[select_slider_type]" id="post-slider" <?php checked($options['select_slider_type'], 'post-slider'); ?> value="post-slider"  />
                                        <?php _e( 'Post Slider', 'catch-everest-pro' ); ?>
                                        </label>

                                        <label title="page-slider" class="box">
                                        <input type="radio" name="catcheverest_options[select_slider_type]" id="page-slider" <?php checked($options['select_slider_type'], 'page-slider'); ?> value="page-slider"  />
                                        <?php _e( 'Page Slider', 'catch-everest-pro' ); ?>
                                        </label>

                                        <label title="category-slider" class="box">
                                        <input type="radio" name="catcheverest_options[select_slider_type]" id="category-slider" <?php checked($options['select_slider_type'], 'category-slider'); ?> value="category-slider"  />
                                        <?php _e( 'Category Slider', 'catch-everest-pro' ); ?>
                                        </label>

                                        <label title="image-slider" class="box">
                                        <input type="radio" name="catcheverest_options[select_slider_type]" id="image-slider" <?php checked($options['select_slider_type'], 'image-slider'); ?> value="image-slider"  />
                                        <?php _e( 'Image Slider', 'catch-everest-pro' ); ?>
                                        </label>
                                    </td>
                                </tr>

                                <tr>
                                    <th scope="row"><label><?php _e( 'Enable Slider', 'catch-everest-pro' ); ?></label></th>
                                    <td>
                                        <label title="enable-slider-homepager" class="box">
                                        <input type="radio" name="catcheverest_options[enable_slider]" id="enable-slider-homepage" <?php checked($options['enable_slider'], 'enable-slider-homepage'); ?> value="enable-slider-homepage"  />
                                        <?php _e( 'Homepage', 'catch-everest-pro' ); ?>
                                        </label>
                                        <label title="enable-slider-allpage" class="box">
                                        <input type="radio" name="catcheverest_options[enable_slider]" id="enable-slider-allpage" <?php checked($options['enable_slider'], 'enable-slider-allpage'); ?> value="enable-slider-allpage"  />
                                         <?php _e( 'Entire Site', 'catch-everest-pro' ); ?>
                                        </label>
                                        <label title="disable-slider" class="box">
                                        <input type="radio" name="catcheverest_options[enable_slider]" id="disable-slider" <?php checked($options['enable_slider'], 'disable-slider'); ?> value="disable-slider"  />
                                         <?php _e( 'Disable', 'catch-everest-pro' ); ?>
                                        </label>
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><?php _e( 'Number of Slides', 'catch-everest-pro' ); ?></th>
                                    <td><input type="text" name="catcheverest_options[slider_qty]" value="<?php echo intval( $options['slider_qty'] ); ?>" size="2" /></td>
                                </tr>
                                <tr>
                                    <th>
                                        <label for="catcheverest_cycle_style"><?php _e( 'Transition Effect:', 'catch-everest-pro' ); ?></label>
                                    </th>
                                    <td>
                                        <select id="catcheverest_cycle_style" name="catcheverest_options[transition_effect]">
                                            <option value="fade" <?php selected('fade', $options['transition_effect']); ?>><?php _e( 'fade', 'catch-everest-pro' ); ?></option>
                                            <option value="wipe" <?php selected('wipe', $options['transition_effect']); ?>><?php _e( 'wipe', 'catch-everest-pro' ); ?></option>
                                            <option value="scrollUp" <?php selected('scrollUp', $options['transition_effect']); ?>><?php _e( 'scrollUp', 'catch-everest-pro' ); ?></option>
                                            <option value="scrollDown" <?php selected('scrollDown', $options['transition_effect']); ?>><?php _e( 'scrollDown', 'catch-everest-pro' ); ?></option>
                                            <option value="scrollLeft" <?php selected('scrollLeft', $options['transition_effect']); ?>><?php _e( 'scrollLeft', 'catch-everest-pro' ); ?></option>
                                            <option value="scrollRight" <?php selected('scrollRight', $options['transition_effect']); ?>><?php _e( 'scrollRight', 'catch-everest-pro' ); ?></option>
                                            <option value="blindX" <?php selected('blindX', $options['transition_effect']); ?>><?php _e( 'blindX', 'catch-everest-pro' ); ?></option>
                                            <option value="blindY" <?php selected('blindY', $options['transition_effect']); ?>><?php _e( 'blindY', 'catch-everest-pro' ); ?></option>
                                            <option value="blindZ" <?php selected('blindZ', $options['transition_effect']); ?>><?php _e( 'blindZ', 'catch-everest-pro' ); ?></option>
                                            <option value="cover" <?php selected('cover', $options['transition_effect']); ?>><?php _e( 'cover', 'catch-everest-pro' ); ?></option>
                                            <option value="shuffle" <?php selected('shuffle', $options['transition_effect']); ?>><?php _e( 'shuffle', 'catch-everest-pro' ); ?></option>
                                        </select>
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><?php _e( 'Transition Delay', 'catch-everest-pro' ); ?></th>
                                    <td>
                                        <input type="text" name="catcheverest_options[transition_delay]" value="<?php echo $options['transition_delay']; ?>" size="2" />
                                       <span class="description"><?php _e( 'second(s)', 'catch-everest-pro' ); ?></span>
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><?php _e( 'Transition Length', 'catch-everest-pro' ); ?></th>
                                    <td>
                                        <input type="text" name="catcheverest_options[transition_duration]" value="<?php echo $options['transition_duration']; ?>" size="2" />
                                        <span class="description"><?php _e( 'second(s)', 'catch-everest-pro' ); ?></span>
                                    </td>
                                </tr>

                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->


                    <div class="option-container post-slider">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Featured Post Slider Options', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tr>
                                    <th scope="row"><?php _e( 'Exclude Slider post from Homepage posts?', 'catch-everest-pro' ); ?></th>
                                     <input type='hidden' value='0' name='catcheverest_options[exclude_slider_post]'>
                                    <td><input type="checkbox" id="headerlogo" name="catcheverest_options[exclude_slider_post]" value="1" <?php checked( '1', $options['exclude_slider_post'] ); ?> /> <?php _e('Check to exclude', 'catch-everest-pro'); ?></td>
                                </tr>
                                <tbody class="sortable">
                                    <?php for ( $i = 1; $i <= $options['slider_qty']; $i++ ): ?>
                                    <tr>
                                        <th scope="row"><label class="handle"><?php _e( 'Featured Slider Post #', 'catch-everest-pro' ); ?><span class="count"><?php echo absint( $i ); ?></span></label></th>
                                        <td><input type="text" name="catcheverest_options[featured_slider][<?php echo absint( $i ); ?>]" value="<?php if( array_key_exists( 'featured_slider', $options ) && array_key_exists( $i, $options['featured_slider'] ) ) echo absint( $options['featured_slider'][ $i ] ); ?>" />
                                        <a href="<?php bloginfo ( 'url' );?>/wp-admin/post.php?post=<?php if( array_key_exists ( 'featured_slider', $options ) && array_key_exists ( $i, $options['featured_slider'] ) ) echo absint( $options['featured_slider'][ $i ] ); ?>&action=edit" class="button" title="<?php esc_attr_e( 'Click Here To Edit', 'catch-everest-pro' ); ?>" target="_blank"><?php _e( 'Click Here To Edit', 'catch-everest-pro' ); ?></a>
                                        </td>
                                    </tr>
                                    <?php endfor; ?>
                                </tbody>
                            </table>
                            <p><?php _e( 'Note: Here You can put your Post IDs which displays on Homepage as slider.', 'catch-everest-pro' ); ?> </p>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container page-slider">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Featured Page Slider Options', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody class="sortable">
                                    <?php for ( $i = 1; $i <= $options['slider_qty']; $i++ ): ?>
                                    <tr>
                                        <th scope="row"><label class="handle"><?php _e( 'Featured Slider Page #', 'catch-everest-pro' ); ?><span class="count"><?php echo absint( $i ); ?></span></label></th>
                                        <td>
                                            <?php
                                                $catcheverest_name = 'catcheverest_options[featured_slider_page][' . absint( $i ) . ']';
                                                $catcheverest_args = array(
                                                                'depth'             => 0,
                                                                'child_of'          => 0,
                                                                'selected'          => ( isset( $options['featured_slider_page'][ $i ] ) && $options['featured_slider_page'][ $i ] > 0 ) ? $options['featured_slider_page'][ $i ] : '',
                                                                'echo'              => 1,
                                                                'name'              => $catcheverest_name,
                                                                'id'                => $catcheverest_name,
                                                                'show_option_none' => '--Select One--',
                                                            );
                                               wp_dropdown_pages( $catcheverest_args );
                                            ?>

                                            <?php if( isset( $options['featured_slider_page'][ $i ] ) && $options['featured_slider_page'][ $i ] > 0 ) : ?>
                                                <a href="<?php bloginfo ( 'url' );?>/wp-admin/post.php?post=<?php if( array_key_exists ( 'featured_slider_page', $options ) && array_key_exists ( $i, $options['featured_slider_page'] ) ) echo absint( $options['featured_slider_page'][ $i ] ); ?>&action=edit" class="button" title="<?php esc_attr_e( 'Click Here To Edit', 'catch-everest-pro' ); ?>" target="_blank"><?php _e( 'Click Here To Edit', 'catch-everest-pro' ); ?></a>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                    <?php endfor; ?>
                                </tbody>
                            </table>
                            <p><?php _e( 'Note: Here You can put your Page IDs which displays on Homepage as slider.', 'catch-everest-pro' ); ?> </p>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container category-slider">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Featured Category Slider Options', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row">
                                            <label for="layouts"><?php _e( 'Select Slider Categories', 'catch-everest-pro' ); ?></label>
                                            <p><small><?php _e( 'Use this only is you want to display posts from Specific Categories in Featured Slider', 'catch-everest-pro' ); ?></small></p>
                                        </th>
                                        <td>
                                            <select name="catcheverest_options[slider_category][]" id="frontpage_posts_cats" multiple="multiple" class="select-multiple">
                                                <option value="0" <?php if ( empty( $options['slider_category'] ) ) { selected( true, true ); } ?>><?php _e( '--Disabled--', 'catch-everest-pro' ); ?></option>
                                                <?php /* Get the list of categories */
                                                    if( empty( $options['slider_category'] ) ) {
                                                        $options['slider_category'] = array();
                                                    }
                                                    $categories = get_categories();
                                                    foreach ( $categories as $category) :
                                                ?>
                                                <option value="<?php echo $category->cat_ID; ?>" <?php if ( in_array( $category->cat_ID, $options['slider_category'] ) ) {echo 'selected="selected"';}?>><?php echo $category->cat_name; ?></option>
                                                <?php endforeach; ?>
                                            </select><br />
                                            <span class="description"><?php _e( 'You may select multiple categories by holding down the CTRL key.', 'catch-everest-pro' ); ?></span>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <p><?php _e( 'Note: Here you can select the categories from which latest posts will display on Featured Slider.', 'catch-everest-pro' ); ?> </p>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container image-slider">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Featured Image Slider Options', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <div id="featured-image-slider">
                                <?php for ( $i = 1; $i <= $options['slider_qty']; $i++ ): ?>
                                    <div class="slides slides-<?php echo $i; ?>">
                                        <h3><?php _e( 'Featured Slide #', 'catch-everest-pro' );?><?php echo $i; ?></h3>
                                        <div class="row">
                                            <div class="col col1">
                                                <?php _e( 'Image', 'catch-everest-pro' );?>
                                            </div>
                                            <div class="col col2">
                                                <input size="90" type="text" class="upload-url" name="catcheverest_options[featured_image_slider_image][<?php echo $i; ?>]" value="<?php if( array_key_exists( 'featured_image_slider_image', $options ) && array_key_exists( $i, $options['featured_image_slider_image'] ) ) echo esc_url( $options['featured_image_slider_image'][ $i ] ); ?>" />
                                                <input ref="<?php esc_attr_e( 'Insert as Featured Slider Image','catch-everest-pro' );?>" class="catcheverest_upload_image button" name="upload_button" type="button" value="<?php esc_attr_e( 'Upload','catch-everest-pro' ); ?>" />
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col col1">
                                                <?php _e( 'Link', 'catch-everest-pro' );?>
                                            </div>
                                            <div class="col col2">
                                                <input size="90" type="text" name="catcheverest_options[featured_image_slider_link][<?php echo absint( $i ); ?>]" value="<?php if( array_key_exists( 'featured_image_slider_link', $options ) && array_key_exists( $i, $options['featured_image_slider_link'] ) ) echo esc_url( $options['featured_image_slider_link'][ $i ] ); ?>" />
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col col1">
                                                <?php _e( 'Target. Open Link in New Window?', 'catch-everest-pro' ); ?>
                                                <input type='hidden' value='0' name='catcheverest_options[featured_image_slider_base][<?php echo absint( $i ); ?>]'>
                                            </div>
                                            <div class="col col2">
                                                <input type="checkbox" name="catcheverest_options[featured_image_slider_base][<?php echo absint( $i ); ?>]" value="1" <?php if( array_key_exists( 'featured_image_slider_base', $options ) && array_key_exists( $i, $options['featured_image_slider_base'] ) ) checked( '1', $options['featured_image_slider_base'][ $i ] ); ?> /> <?php _e( 'Check to open in new window', 'catch-everest-pro' ); ?>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col col1">
                                                <?php _e( 'Title', 'catch-everest-pro' ); ?>
                                            </div>
                                            <div class="col col2">
                                                <input size="90" type="text" name="catcheverest_options[featured_image_slider_title][<?php echo absint( $i ); ?>]" value="<?php if( array_key_exists( 'featured_image_slider_title', $options ) && array_key_exists( $i, $options['featured_image_slider_title'] ) ) echo esc_attr( $options['featured_image_slider_title'][ $i ] ); ?>" />
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col col1">
                                                <?php _e( 'Content', 'catch-everest-pro' ); ?>
                                            </div>
                                            <div class="col col2"><textarea name="catcheverest_options[featured_image_slider_content][<?php echo absint( $i ); ?>]" cols="100" rows="3"><?php if( array_key_exists( 'featured_image_slider_content', $options ) && array_key_exists( $i, $options['featured_image_slider_content'] ) ) echo esc_html( $options['featured_image_slider_content'][ $i ] ); ?></textarea></div>
                                        </div>
                                        <div class="row">
                                            <div class="col col1">
                                                <?php _e( 'Author', 'catch-everest-pro' ); ?>
                                            </div>
                                            <div class="col col2">
                                             <?php
                                                if( array_key_exists( 'featured_image_slider_author', $options ) && array_key_exists( $i, $options['featured_image_slider_author'] ) ) {
                                                    $author =  $options['featured_image_slider_author'][ $i ];
                                                }
                                                else {
                                                    $author = 0;
                                                }

                                                wp_dropdown_users( array(
                                                            'name'              => 'catcheverest_options[featured_image_slider_author][' . absint( $i ) . ']',
                                                            'selected'          => absint( $author ),
                                                            'orderby'           => 'ID',
                                                            )
                                                        );
                                            ?>
                                            </div>
                                        </div>
                                        <div class="clear"></div>
                                    </div> <!-- .slides -->
                                <?php endfor; ?>
                            </div> <!-- .featured-image-slider -->
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                </div><!-- #slidersettings -->


                <!-- Options for Social Links -->
                <div id="sociallinks">
                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Predefine Social Icons', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Facebook', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_facebook]" value="<?php echo esc_url( $options['social_facebook'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Twitter', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_twitter]" value="<?php echo esc_url( $options[ 'social_twitter'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Google+', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_googleplus]" value="<?php echo esc_url( $options[ 'social_googleplus'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Pinterest', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_pinterest]" value="<?php echo esc_url( $options[ 'social_pinterest'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Youtube', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_youtube]" value="<?php echo esc_url( $options['social_youtube'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Vimeo', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_vimeo]" value="<?php echo esc_url( $options['social_vimeo'] ); ?>" />
                                        </td>
                                    </tr>

                                    <tr>
                                        <th scope="row"><?php _e( 'Linkedin', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_linkedin]" value="<?php echo esc_url( $options[ 'social_linkedin'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Slideshare', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_slideshare]" value="<?php echo esc_url( $options[ 'social_slideshare'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Foursquare', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_foursquare]" value="<?php echo esc_url( $options['social_foursquare'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Flickr', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_flickr]" value="<?php echo esc_url( $options['social_flickr'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Tumblr', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_tumblr]" value="<?php echo esc_url( $options['social_tumblr'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'deviantART', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_deviantart]" value="<?php echo esc_url( $options['social_deviantart'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Dribbble', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_dribbble]" value="<?php echo esc_url( $options['social_dribbble'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'MySpace', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_myspace]" value="<?php echo esc_url( $options['social_myspace'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'WordPress', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_wordpress]" value="<?php echo esc_url( $options['social_wordpress'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'RSS', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_rss]" value="<?php echo esc_url( $options['social_rss'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Delicious', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_delicious]" value="<?php echo esc_url( $options['social_delicious'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Last.fm', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_lastfm]" value="<?php echo esc_url( $options['social_lastfm'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Instagram', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_instagram]" value="<?php echo esc_url( $options['social_instagram'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'GitHub', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_github]" value="<?php echo esc_url( $options['social_github'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Vkontakte', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_vkontakte]" value="<?php echo esc_url( $options[ 'social_vkontakte'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'My World', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_myworld]" value="<?php echo esc_url( $options['social_myworld'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Odnoklassniki', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_odnoklassniki]" value="<?php echo esc_url( $options['social_odnoklassniki'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Goodreads', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_goodreads]" value="<?php echo esc_url( $options['social_goodreads'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Skype', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_skype]" value="<?php echo esc_attr( $options['social_skype'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Soundcloud', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_soundcloud]" value="<?php echo esc_url( $options['social_soundcloud'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Email', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_email]" value="<?php echo sanitize_email( $options['social_email'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Contact', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_contact]" value="<?php echo esc_url( $options['social_contact'] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Xing', 'catch-everest-pro' ); ?></th>
                                        <td><input type="text" size="45" name="catcheverest_options[social_xing]" value="<?php echo esc_attr( $options['social_xing'] ); ?>" />
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>                       </div><!-- .option-content -->
                    </div><!-- .option-container -->

<div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Custom Social Icons', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Number of Custom Social Icons', 'catch-everest-pro' ); ?></th>
                                        <td>
                                            <input type="text" size="2" name="catcheverest_options[social_custom_qty]" value="<?php echo intval( $options['social_custom_qty'] ); ?>" size="2" />
                                        </td>
                                    </tr>

                                    <?php for ( $i = 1; $i <= $options['social_custom_qty']; $i++ ): ?>
                                        <tr>
                                            <th scope="row">
                                                <strong><?php printf( esc_attr__( 'Custom Social Icon #%s', 'catch-everest-pro' ), $i ); ?></strong>
                                            </th>
                                        </tr>
                                        <tr>
                                            <th scope="row"><?php printf( esc_attr__( 'Social Icon Name #%s', 'catch-everest-pro' ), $i ); ?></th>
                                            <td>
                                                <input type="text" size="65" name="catcheverest_options[social_custom_name][<?php echo absint( $i ); ?>]" value="<?php if( array_key_exists( 'social_custom_name', $options ) && array_key_exists( $i, $options['social_custom_name'] ) ) echo esc_attr( $options['social_custom_name'][ $i ] ); ?>" />
                                            </td>
                                        </tr>
                                        <tr>
                                            <th scope="row">
                                                <?php printf( esc_attr__( 'Social Icon Image URL #%s', 'catch-everest-pro' ), $i ); ?>
                                            </th>
                                            <td>
                                                <input class="upload-url" size="65" type="text" name="catcheverest_options[social_custom_image][<?php echo $i; ?>]" value="<?php if( array_key_exists( 'social_custom_image', $options ) && array_key_exists( $i, $options['social_custom_image'] ) ) echo esc_url( $options['social_custom_image'][ $i ] ); ?>" />
                                                <input ref="<?php printf( esc_attr__( 'Insert as Social Icon Image #%s', 'catch-everest-pro' ), $i ); ?>" class="catcheverest_upload_image button" name="wsl-image-add" type="button" value="<?php if( array_key_exists( 'social_custom_image', $options ) && array_key_exists( $i, $options['social_custom_image'] ) ) { esc_attr_e( 'Change Image','catch-everest-pro' ); } else { esc_attr_e( 'Add Image','catch-everest-pro' ); } ?>" />
                                            </td>
                                        </tr>
                                        <tr>
                                            <th scope="row">
                                                <?php printf( esc_attr__( 'Social Icon Image URL on Hover #%s', 'catch-everest-pro' ), $i ); ?>
                                            </th>
                                            <td>
                                                <input class="upload-url" size="65" type="text" name="catcheverest_options[social_custom_image_hover][<?php echo $i; ?>]" value="<?php if( array_key_exists( 'social_custom_image_hover', $options ) && array_key_exists( $i, $options['social_custom_image_hover'] ) ) echo esc_url( $options['social_custom_image_hover'][ $i ] ); ?>" />
                                                <input ref="<?php printf( esc_attr__( 'Insert as Social Icon Image #%s', 'catch-everest-pro' ), $i ); ?>" class="catcheverest_upload_image button" name="wsl-image-add" type="button" value="<?php if( array_key_exists( 'social_custom_image_hover', $options ) && array_key_exists( $i, $options['social_custom_image_hover'] ) ) { esc_attr_e( 'Change Image','catch-everest-pro' ); } else { esc_attr_e( 'Add Image','catch-everest-pro' ); } ?>" />
                                            </td>
                                        </tr>
                                        <tr>
                                            <th scope="row"><label><?php printf( esc_attr__( 'Social Icon URL #%s', 'catch-everest-pro' ), $i ); ?></label></th>
                                            <td><input type="text" size="65" name="catcheverest_options[social_custom_url][<?php echo absint( $i ); ?>]" value="<?php if( array_key_exists( 'social_custom_url', $options ) && array_key_exists( $i, $options['social_custom_url'] ) ) echo esc_url( $options['social_custom_url'][ $i ] ); ?>" />
                                            </td>
                                        </tr>
                                    <?php endfor; ?>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>                       </div><!-- .option-content -->
                    </div><!-- .option-container -->

                </div><!-- #slidersettings -->


                <!-- Options for Webmaster Tools -->
                <div id="webmaster">
                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Site Verification', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Google Site Verification ID', 'catch-everest-pro' ); ?></label></th>
                                        <td><input type="text" size="45" name="catcheverest_options[google_verification]" value="<?php echo esc_attr( $options['google_verification'] ); ?>" /> <?php _e('Enter your Google ID number only', 'catch-everest-pro'); ?>
                                        </td>
                                    </tr>

                                    <tr>
                                        <th scope="row"><label><?php _e( 'Yahoo Site Verification ID', 'catch-everest-pro' ); ?></label></th>
                                        <td><input type="text" size="45" name="catcheverest_options[yahoo_verification]" value="<?php echo esc_attr( $options[ 'yahoo_verification'] ); ?>" /> <?php _e('Enter your Yahoo ID number only', 'catch-everest-pro'); ?>
                                        </td>
                                    </tr>

                                    <tr>
                                        <th scope="row"><label><?php _e( 'Bing Site Verification ID', 'catch-everest-pro' ); ?></label></th>
                                        <td><input type="text" size="45" name="catcheverest_options[bing_verification]" value="<?php echo esc_attr( $options['bing_verification'] ); ?>" /> <?php _e('Enter your Bing ID number only', 'catch-everest-pro'); ?>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Header and Footer Codes', 'catch-everest-pro' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Code to display on Header', 'catch-everest-pro' ); ?></th>
                                        <td>
                                        <textarea name="catcheverest_options[analytic_header]" id="analytics" rows="7" cols="80" ><?php echo esc_html( $options['analytic_header'] ); ?></textarea>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td></td><td><?php _e('Note: Note: Here you can put scripts from Google, Facebook, Twitter, Add This etc. which will load on Header', 'catch-everest-pro' ); ?></td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e('Code to display on Footer', 'catch-everest-pro' ); ?></th>
                                        <td>
                                         <textarea name="catcheverest_options[analytic_footer]" id="analytics" rows="7" cols="80" ><?php echo esc_html( $options['analytic_footer'] ); ?></textarea>

                                        </td>
                                    </tr>
                                    <tr>
                                        <td></td><td><?php _e( 'Note: Here you can put scripts from Google, Facebook, Twitter, Add This etc. which will load on footer', 'catch-everest-pro' ); ?></td>
                                    </tr>
                                </tbody>
                            </table>

                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-everest-pro' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->
                </div><!-- #webmaster -->

            </div><!-- #catcheverest_ad_tabs -->
        </form>
    </div><!-- .wrap -->
<?php
}


/**
 * Validate content options
 * @param array $options
 * @uses esc_url_raw, absint, esc_textarea, sanitize_text_field, catcheverest_invalidate_caches
 * @return array
 */
function catcheverest_theme_options_validate( $options ) {
    global $catcheverest_options_settings, $catcheverest_options_defaults;
    $input_validated = $catcheverest_options_settings;

    $defaults = $catcheverest_options_defaults;

    if( "1" == $options['reset_all_settings'] ) {
        return $defaults;
    }

    $fonts = catcheverest_available_fonts();

    $input = array();
    $input = $options;

    // Data Validation for Primary Menu disable
    if ( isset( $input['disable_primary_menu'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'disable_primary_menu' ] = $input[ 'disable_primary_menu' ];
    }
    // Data Validation for Resonsive Design
    if ( isset( $input['disable_responsive'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'disable_responsive' ] = $input[ 'disable_responsive' ];
    }
    if ( isset( $input['enable_responsive_zoom'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'enable_responsive_zoom' ] = $input[ 'enable_responsive_zoom' ];
    }
    if ( isset( $input['enable_menus'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'enable_menus' ] = $input[ 'enable_menus' ];
    }

    // Data Validation for Header Sidebar
    if ( isset( $input[ 'disable_header_right_sidebar' ] ) ) {
        $input_validated[ 'disable_header_right_sidebar' ] = $input[ 'disable_header_right_sidebar' ];
    }

    // Data validation for Move Site Title above Header Image
    if ( isset( $input['site_title_above'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'site_title_above' ] = $input[ 'site_title_above' ];
    }
    // Data validation for Large Header Image
    if ( isset( $input[ 'featured_header_image' ] ) ) {
        $input_validated[ 'featured_header_image' ] = esc_url_raw( $input[ 'featured_header_image' ] ) ? $input [ 'featured_header_image' ] : $defaults[ 'featured_header_image' ];
    }
    if ( isset( $input[ 'featured_header_image_alt' ] ) ) {
        $input_validated[ 'featured_header_image_alt' ] = sanitize_text_field( $input[ 'featured_header_image_alt' ] );
    }
    if ( isset( $input[ 'featured_header_image_url' ] ) ) {
        $input_validated[ 'featured_header_image_url' ] = esc_url_raw( $input[ 'featured_header_image_url' ] );
    }
    if ( isset( $input['featured_header_image_base'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'featured_header_image_base' ] = $input[ 'featured_header_image_base' ];
    }

    if ( isset( $input[ 'featured_header_image_position' ] ) ) {
        $input_validated[ 'featured_header_image_position' ] = $input[ 'featured_header_image_position' ];
    }
    if ( isset( $input[ 'enable_featured_header_image' ] ) ) {
        $input_validated[ 'enable_featured_header_image' ] = $input[ 'enable_featured_header_image' ];
    }
    if ( isset( $input['page_featured_image'] ) ) {
        $input_validated[ 'page_featured_image' ] = $input[ 'page_featured_image' ];
    }

    // Data Validation for Favicon
    if ( isset( $input[ 'fav_icon' ] ) ) {
        $input_validated[ 'fav_icon' ] = esc_url_raw( $input[ 'fav_icon' ] );
    }
    if ( isset( $input['remove_favicon'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'remove_favicon' ] = $input[ 'remove_favicon' ];
    }

    // Data Validation for web clip icon
    if ( isset( $input[ 'web_clip' ] ) ) {
        $input_validated[ 'web_clip' ] = esc_url_raw( $input[ 'web_clip' ] );
    }
    if ( isset( $input['remove_web_clip'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'remove_web_clip' ] = $input[ 'remove_web_clip' ];
    }

    // data validation for Color Scheme
    if ( isset( $input['color_scheme'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'color_scheme' ] = $input[ 'color_scheme' ];
    }

    // data validation for Color Options
    if( isset( $input[ 'header_background' ] ) ) {
        $input_validated[ 'header_background' ] = wp_filter_nohtml_kses( $input[ 'header_background' ] );
    }
    if( isset( $input[ 'content_background' ] ) ) {
        $input_validated[ 'content_background' ] = wp_filter_nohtml_kses( $input[ 'content_background' ] );
    }
    if( isset( $input[ 'footer_sidebar_background' ] ) ) {
        $input_validated[ 'footer_sidebar_background' ] = wp_filter_nohtml_kses( $input[ 'footer_sidebar_background' ] );
    }
    if( isset( $input[ 'footer_background' ] ) ) {
        $input_validated[ 'footer_background' ] = wp_filter_nohtml_kses( $input[ 'footer_background' ] );
    }
    if( isset( $input[ 'title_color' ] ) ) {
        $input_validated[ 'title_color' ] = wp_filter_nohtml_kses( $input[ 'title_color' ] );
    }
    if( isset( $input[ 'title_hover_color' ] ) ) {
        $input_validated[ 'title_hover_color' ] = wp_filter_nohtml_kses( $input[ 'title_hover_color' ] );
    }
    if( isset( $input[ 'meta_color' ] ) ) {
        $input_validated[ 'meta_color' ] = wp_filter_nohtml_kses( $input[ 'meta_color' ] );
    }
    if( isset( $input[ 'text_color' ] ) ) {
        $input_validated[ 'text_color' ] = wp_filter_nohtml_kses( $input[ 'text_color' ] );
    }
    if( isset( $input[ 'link_color' ] ) ) {
        $input_validated[ 'link_color' ] = wp_filter_nohtml_kses( $input[ 'link_color' ] );
    }
    if( isset( $input[ 'widget_title_color' ] ) ) {
        $input_validated[ 'widget_title_color' ] = wp_filter_nohtml_kses( $input[ 'widget_title_color' ] );
    }
    if( isset( $input[ 'widget_color' ] ) ) {
        $input_validated[ 'widget_color' ] = wp_filter_nohtml_kses( $input[ 'widget_color' ] );
    }
    if( isset( $input[ 'widget_link_color' ] ) ) {
        $input_validated[ 'widget_link_color' ] = wp_filter_nohtml_kses( $input[ 'widget_link_color' ] );
    }
    if( isset( $input[ 'home_headline_background' ] ) ) {
        $input_validated[ 'home_headline_background' ] = wp_filter_nohtml_kses( $input[ 'home_headline_background' ] );
    }
    if( isset( $input[ 'home_headline' ] ) ) {
        $input_validated[ 'home_headline' ] = wp_filter_nohtml_kses( $input[ 'home_headline' ] );
    }
    if( isset( $input[ 'menu_background' ] ) ) {
        $input_validated[ 'menu_background' ] = wp_filter_nohtml_kses( $input[ 'menu_background' ] );
    }
    if( isset( $input[ 'menu_color' ] ) ) {
        $input_validated[ 'menu_color' ] = wp_filter_nohtml_kses( $input[ 'menu_color' ] );
    }
    if( isset( $input[ 'hover_active_color' ] ) ) {
        $input_validated[ 'hover_active_color' ] = wp_filter_nohtml_kses( $input[ 'hover_active_color' ] );
    }
    if( isset( $input[ 'hover_active_text_color' ] ) ) {
        $input_validated[ 'hover_active_text_color' ] = wp_filter_nohtml_kses( $input[ 'hover_active_text_color' ] );
    }
    if( isset( $input[ 'sub_menu_bg_color' ] ) ) {
        $input_validated[ 'sub_menu_bg_color' ] = wp_filter_nohtml_kses( $input[ 'sub_menu_bg_color' ] );
    }
    if( isset( $input[ 'sub_menu_text_color' ] ) ) {
        $input_validated[ 'sub_menu_text_color' ] = wp_filter_nohtml_kses( $input[ 'sub_menu_text_color' ] );
    }
    if( isset( $input[ 'scrollup_bg_color' ] ) ) {
        $input_validated[ 'scrollup_bg_color' ] = wp_filter_nohtml_kses( $input[ 'scrollup_bg_color' ] );
    }
    if( isset( $input[ 'scrollup_text_color' ] ) ) {
        $input_validated[ 'scrollup_text_color' ] = wp_filter_nohtml_kses( $input[ 'scrollup_text_color' ] );
    }

    if ( isset( $input['reset_color'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'reset_color' ] = $input[ 'reset_color' ];
    }

    //Reset Color Options
    if( $input[ 'reset_color' ] == 1 ) {
        $input_validated[ 'color_scheme' ]              = $defaults[ 'color_scheme' ];
        $input_validated[ 'header_background' ]         = $defaults[ 'header_background' ];
        $input_validated[ 'content_background' ]        = $defaults[ 'content_background' ];
        $input_validated[ 'footer_sidebar_background' ] = $defaults[ 'footer_sidebar_background' ];
        $input_validated[ 'footer_background' ]         = $defaults[ 'footer_background' ];
        $input_validated[ 'title_color' ]               = $defaults[ 'title_color' ];
        $input_validated[ 'title_hover_color' ]         = $defaults[ 'title_hover_color' ];
        $input_validated[ 'meta_color' ]                = $defaults[ 'meta_color' ];
        $input_validated[ 'text_color' ]                = $defaults[ 'text_color' ];
        $input_validated[ 'link_color' ]                = $defaults[ 'link_color' ];
        $input_validated[ 'widget_title_color' ]        = $defaults[ 'widget_title_color' ];
        $input_validated[ 'widget_color' ]              = $defaults[ 'widget_color' ];
        $input_validated[ 'widget_link_color' ]         = $defaults[ 'widget_link_color' ];
        $input_validated[ 'home_headline_background' ]  = $defaults[ 'home_headline_background' ];
        $input_validated[ 'home_headline' ]             = $defaults[ 'home_headline' ];
        $input_validated[ 'menu_background' ]           = $defaults[ 'menu_background' ];
        $input_validated[ 'menu_color' ]                = $defaults[ 'menu_color' ];
        $input_validated[ 'hover_active_color' ]        = $defaults[ 'hover_active_color' ];
        $input_validated[ 'hover_active_text_color' ]   = $defaults[ 'hover_active_text_color' ];
        $input_validated[ 'sub_menu_bg_color' ]         = $defaults[ 'sub_menu_bg_color' ];
        $input_validated[ 'sub_menu_text_color' ]       = $defaults[ 'sub_menu_text_color' ];
        $input_validated[ 'scrollup_bg_color' ]         = $defaults[ 'scrollup_bg_color' ];
        $input_validated[ 'scrollup_text_color' ]       = $defaults[ 'scrollup_text_color' ];
        $input_validated[ 'reset_color' ]               = "0";
    }

    // data validation for Font Family Options
    if( isset( $input[ 'reset_typography'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'reset_typography' ] = $input[ 'reset_typography' ];
        $input_validated['body_font'] = ( array_key_exists( $input['body_font'], $fonts ) ? $input['body_font'] : $defaults[ 'body_font' ] );
        $input_validated['title_font'] = ( array_key_exists( $input['title_font'], $fonts ) ? $input['title_font'] : $defaults[ 'title_font' ] );
        $input_validated['tagline_font'] = ( array_key_exists( $input['title_font'], $fonts ) ? $input['tagline_font'] : $defaults[ 'tagline_font' ] );
        $input_validated['content_tittle_font'] = ( array_key_exists( $input['content_tittle_font'], $fonts ) ? $input['content_tittle_font'] : $defaults[ 'content_tittle_font' ] );
        $input_validated['content_font'] = ( array_key_exists( $input['content_font'], $fonts ) ? $input['content_font'] : $defaults[ 'content_font' ] );
        $input_validated['headings_font'] = ( array_key_exists( $input['headings_font'], $fonts ) ? $input['headings_font'] : $defaults[ 'headings_font' ] );

        if( $input[ 'reset_typography'] == '1' ) {
            $input_validated['body_font']           = $defaults[ 'body_font' ];
            $input_validated['title_font']          = $defaults[ 'title_font' ];
            $input_validated['tagline_font']        = $defaults[ 'tagline_font' ];
            $input_validated['content_tittle_font'] = $defaults[ 'content_tittle_font' ];
            $input_validated['content_font']        = $defaults[ 'content_font' ];
            $input_validated['headings_font']       = $defaults[ 'headings_font' ];
            $input_validated[ 'reset_typography' ]  = "0";
        }
    }

    // Data Validation for WooCommerce Options
    if ( isset( $input[ 'disable_product_gallery_zoom' ] ) ) {
        $input_validated[ 'disable_product_gallery_zoom' ] = $input[ 'disable_product_gallery_zoom' ];
    }
    if ( isset( $input[ 'disable_product_gallery_lightbox' ] ) ) {
        $input_validated[ 'disable_product_gallery_lightbox' ] = $input[ 'disable_product_gallery_lightbox' ];
    }
    if ( isset( $input[ 'disable_product_gallery_slider' ] ) ) {
        $input_validated[ 'disable_product_gallery_slider' ] = $input[ 'disable_product_gallery_slider' ];
    }

    // Data Validation for Comment Setting
    if ( isset( $input[ 'commenting_setting' ] ) ) {
        $input_validated[ 'commenting_setting' ] = $input[ 'commenting_setting' ];
    }

    // Data Validation for Custom CSS Style
    // @remove if block when WP 5.0 is released
    if ( ! function_exists( 'wp_update_custom_css_post' )  && isset( $input['custom_css'] ) ) {
        $input_validated['custom_css'] = wp_kses_stripslashes($input['custom_css']);
    }

    // Data Validation for Homepage Headline Message
    if( isset( $input[ 'homepage_headline' ] ) ) {
        $input_validated['homepage_headline'] =  sanitize_text_field( $input[ 'homepage_headline' ] ) ? $input [ 'homepage_headline' ] : $defaults[ 'homepage_headline' ];
    }
    if( isset( $input[ 'homepage_subheadline' ] ) ) {
        $input_validated['homepage_subheadline'] =  sanitize_text_field( $input[ 'homepage_subheadline' ] ) ? $input [ 'homepage_subheadline' ] : $defaults[ 'homepage_subheadline' ];
    }
    if ( isset( $input[ 'disable_homepage_headline' ] ) ) {
        $input_validated[ 'disable_homepage_headline' ] = $input[ 'disable_homepage_headline' ];
    }
    if ( isset( $input[ 'disable_homepage_subheadline' ] ) ) {
        $input_validated[ 'disable_homepage_subheadline' ] = $input[ 'disable_homepage_subheadline' ];
    }

    // Data Validation for Homepage Featured Content
    if ( isset( $input[ 'disable_homepage_featured' ] ) ) {
        $input_validated[ 'disable_homepage_featured' ] = $input[ 'disable_homepage_featured' ];
    }
    if( isset( $input[ 'homepage_featured_headline' ] ) ) {
        $input_validated['homepage_featured_headline'] =  sanitize_text_field( $input[ 'homepage_featured_headline' ] ) ? $input [ 'homepage_featured_headline' ] : $defaults[ 'homepage_featured_headline' ];
    }
    if ( isset( $input[ 'homepage_featured_image' ] ) ) {
        $input_validated[ 'homepage_featured_image' ] = array();
    }
    if ( isset( $input[ 'homepage_featured_url' ] ) ) {
        $input_validated[ 'homepage_featured_url' ] = array();
    }
    if ( isset( $input[ 'homepage_featured_base' ] ) ) {
        $input_validated[ 'homepage_featured_base' ] = array();
    }
    if ( isset( $input[ 'homepage_featured_title' ] ) ) {
        $input_validated[ 'homepage_featured_title' ] = array();
    }
    if ( isset( $input[ 'homepage_featured_content' ] ) ) {
        $input_validated[ 'homepage_featured_content' ] = array();
    }
    if( isset( $input[ 'homepage_featured_layout' ] ) ) {
        $input_validated[ 'homepage_featured_layout' ] = $input[ 'homepage_featured_layout' ];
    }
    if ( isset( $input[ 'homepage_featured_author' ] ) ) {
        $input_validated[ 'homepage_featured_author' ] = array();
    }
    if ( isset( $input[ 'homepage_featured_qty' ] ) ) {
        $input_validated[ 'homepage_featured_qty' ] = absint( $input[ 'homepage_featured_qty' ] ) ? $input [ 'homepage_featured_qty' ] : $defaults[ 'homepage_featured_qty' ];
        for ( $i = 1; $i <= $input [ 'homepage_featured_qty' ]; $i++ ) {
            if ( !empty( $input[ 'homepage_featured_image' ][ $i ] ) ) {
                $input_validated[ 'homepage_featured_image' ][ $i ] = esc_url_raw($input[ 'homepage_featured_image' ][ $i ] );
            }
            if ( !empty( $input[ 'homepage_featured_url' ][ $i ] ) ) {
                $input_validated[ 'homepage_featured_url'][ $i ] = esc_url_raw($input[ 'homepage_featured_url'][ $i ]);
            }
            if ( !empty( $input[ 'homepage_featured_base' ][ $i ] ) ) {
                $input_validated[ 'homepage_featured_base'][ $i ] = $input[ 'homepage_featured_base'][ $i ];
            }
            if ( !empty( $input[ 'homepage_featured_title' ][ $i ] ) ) {
                $input_validated[ 'homepage_featured_title'][ $i ] = sanitize_text_field($input[ 'homepage_featured_title'][ $i ]);
            }
            if ( !empty( $input[ 'homepage_featured_content' ][ $i ] ) ) {
                $input_validated[ 'homepage_featured_content'][ $i ] = wp_kses_stripslashes($input[ 'homepage_featured_content'][ $i ]);
            }
            if ( !empty( $input[ 'homepage_featured_author' ][ $i ] ) ) {
                $input_validated[ 'homepage_featured_author'][ $i ] = absint( $input[ 'homepage_featured_author'][ $i ]);
            }
        }
    }

    // Data Validation for Homepage
    if ( isset( $input[ 'enable_posts_home' ] ) ) {
        $input_validated[ 'enable_posts_home' ] = $input[ 'enable_posts_home' ];
    }
    if ( isset( $input[ 'move_posts_home' ] ) ) {
        $input_validated[ 'move_posts_home' ] = $input[ 'move_posts_home' ];
    }


    if ( isset( $input['exclude_slider_post'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'exclude_slider_post' ] = $input[ 'exclude_slider_post' ];

    }
    // Front page posts categories
    if( isset( $input['front_page_category' ] ) ) {
        if( in_array( 0, $input['front_page_category'] ) ) {
            $input_validated[ 'front_page_category' ] = '0';
        }
        else{
            $input_validated['front_page_category'] = $input['front_page_category'];
        }
    }

    // data validation for Slider Type
    if( isset( $input[ 'select_slider_type' ] ) ) {
        $input_validated[ 'select_slider_type' ] = $input[ 'select_slider_type' ];
    }
    // data validation for Enable Slider
    if( isset( $input[ 'enable_slider' ] ) ) {
        $input_validated[ 'enable_slider' ] = $input[ 'enable_slider' ];
    }
    // data validation for number of slides
    if ( isset( $input[ 'slider_qty' ] ) ) {
        $input_validated[ 'slider_qty' ] = absint( $input[ 'slider_qty' ] ) ? $input [ 'slider_qty' ] : 4;
    }
    // data validation for transition effect
    if( isset( $input[ 'transition_effect' ] ) ) {
        $input_validated['transition_effect'] = wp_filter_nohtml_kses( $input['transition_effect'] );
    }
    // data validation for transition delay
    if ( isset( $input[ 'transition_delay' ] ) && is_numeric( $input[ 'transition_delay' ] ) ) {
        $input_validated[ 'transition_delay' ] = $input[ 'transition_delay' ];
    }
    // data validation for transition length
    if ( isset( $input[ 'transition_duration' ] ) && is_numeric( $input[ 'transition_duration' ] ) ) {
        $input_validated[ 'transition_duration' ] = $input[ 'transition_duration' ];
    }

    // data validation for Featured Post and Page Slider
    if ( isset( $input[ 'featured_slider' ] ) ) {
        $input_validated[ 'featured_slider' ] = array();
    }
    if ( isset( $input[ 'featured_slider_page' ] ) ) {
        $input_validated[ 'featured_slider_page' ] = array();
    }
    if ( isset( $input[ 'slider_qty' ] ) )  {
        for ( $i = 1; $i <= $input [ 'slider_qty' ]; $i++ ) {
            if ( !empty( $input[ 'featured_slider' ][ $i ] ) && intval( $input[ 'featured_slider' ][ $i ] ) ) {
                $input_validated[ 'featured_slider' ][ $i ] = absint($input[ 'featured_slider' ][ $i ] );
            }
            if ( !empty( $input[ 'featured_slider_page' ][ $i ] ) && intval( $input[ 'featured_slider_page' ][ $i ] ) ) {
                $input_validated[ 'featured_slider_page' ][ $i ] = absint($input[ 'featured_slider_page' ][ $i ] );
            }
        }
    }

    //Featured Catgory Slider
    if ( isset( $input['slider_category'] ) ) {
        if( in_array( 0, $input['slider_category'] ) ) {
            $input_validated[ 'slider_category' ] = '0';
        }
        else{
            $input_validated[ 'slider_category' ] = $input[ 'slider_category' ];
        }
    }

    // data validation for Featured Image SLider
    if ( isset( $input[ 'featured_image_slider_image' ] ) ) {
        $input_validated[ 'featured_image_slider_image' ] = array();
    }
    if ( isset( $input[ 'featured_image_slider_link' ] ) ) {
        $input_validated[ 'featured_image_slider_link' ] = array();
    }
    if ( isset( $input[ 'featured_image_slider_base' ] ) ) {
        $input_validated[ 'featured_image_slider_base' ] = array();
    }
    if ( isset( $input[ 'featured_image_slider_title' ] ) ) {
        $input_validated[ 'featured_image_slider_title' ] = array();
    }
    if ( isset( $input[ 'featured_image_slider_content' ] ) ) {
        $input_validated[ 'featured_image_slider_content' ] = array();
    }
    if ( isset( $input[ 'featured_image_slider_author' ] ) ) {
        $input_validated[ 'featured_image_slider_author' ] = array();
    }
    if ( isset( $input[ 'slider_qty' ] ) )  {
        for ( $i = 1; $i <= $input [ 'slider_qty' ]; $i++ ) {
            if ( !empty( $input[ 'featured_image_slider_image' ][ $i ] ) ) {
                $input_validated[ 'featured_image_slider_image' ][ $i ] = esc_url_raw($input[ 'featured_image_slider_image' ][ $i ] );
            }
            if ( !empty( $input[ 'featured_image_slider_link' ][ $i ] ) ) {
                $input_validated[ 'featured_image_slider_link'][ $i ] = esc_url_raw($input[ 'featured_image_slider_link'][ $i ]);
            }
            if ( !empty( $input[ 'featured_image_slider_base' ][ $i ] ) ) {
                $input_validated[ 'featured_image_slider_base'][ $i ] = $input[ 'featured_image_slider_base'][ $i ];
            }
            if ( !empty( $input[ 'featured_image_slider_title' ][ $i ] ) ) {
                $input_validated[ 'featured_image_slider_title'][ $i ] = sanitize_text_field($input[ 'featured_image_slider_title'][ $i ]);
            }
            if ( !empty( $input[ 'featured_image_slider_content' ][ $i ] ) ) {
                $input_validated[ 'featured_image_slider_content'][ $i ] = wp_kses_stripslashes($input[ 'featured_image_slider_content'][ $i ]);
            }
            if ( !empty( $input[ 'featured_image_slider_author' ][ $i ] ) ) {
                $input_validated[ 'featured_image_slider_author'][ $i ] = absint($input[ 'featured_image_slider_author'][ $i ]);
            }
        }
    }

    // data validation for Social Icons
    if( isset( $input[ 'social_facebook' ] ) ) {
        $input_validated[ 'social_facebook' ] = esc_url_raw( $input[ 'social_facebook' ] );
    }
    if( isset( $input[ 'social_twitter' ] ) ) {
        $input_validated[ 'social_twitter' ] = esc_url_raw( $input[ 'social_twitter' ] );
    }
    if( isset( $input[ 'social_googleplus' ] ) ) {
        $input_validated[ 'social_googleplus' ] = esc_url_raw( $input[ 'social_googleplus' ] );
    }
    if( isset( $input[ 'social_pinterest' ] ) ) {
        $input_validated[ 'social_pinterest' ] = esc_url_raw( $input[ 'social_pinterest' ] );
    }
    if( isset( $input[ 'social_youtube' ] ) ) {
        $input_validated[ 'social_youtube' ] = esc_url_raw( $input[ 'social_youtube' ] );
    }
    if( isset( $input[ 'social_vimeo' ] ) ) {
        $input_validated[ 'social_vimeo' ] = esc_url_raw( $input[ 'social_vimeo' ] );
    }
    if( isset( $input[ 'social_linkedin' ] ) ) {
        $input_validated[ 'social_linkedin' ] = esc_url_raw( $input[ 'social_linkedin' ] );
    }
    if( isset( $input[ 'social_slideshare' ] ) ) {
        $input_validated[ 'social_slideshare' ] = esc_url_raw( $input[ 'social_slideshare' ] );
    }
    if( isset( $input[ 'social_foursquare' ] ) ) {
        $input_validated[ 'social_foursquare' ] = esc_url_raw( $input[ 'social_foursquare' ] );
    }
    if( isset( $input[ 'social_flickr' ] ) ) {
        $input_validated[ 'social_flickr' ] = esc_url_raw( $input[ 'social_flickr' ] );
    }
    if( isset( $input[ 'social_tumblr' ] ) ) {
        $input_validated[ 'social_tumblr' ] = esc_url_raw( $input[ 'social_tumblr' ] );
    }
    if( isset( $input[ 'social_deviantart' ] ) ) {
        $input_validated[ 'social_deviantart' ] = esc_url_raw( $input[ 'social_deviantart' ] );
    }
    if( isset( $input[ 'social_dribbble' ] ) ) {
        $input_validated[ 'social_dribbble' ] = esc_url_raw( $input[ 'social_dribbble' ] );
    }
    if( isset( $input[ 'social_myspace' ] ) ) {
        $input_validated[ 'social_myspace' ] = esc_url_raw( $input[ 'social_myspace' ] );
    }
    if( isset( $input[ 'social_wordpress' ] ) ) {
        $input_validated[ 'social_wordpress' ] = esc_url_raw( $input[ 'social_wordpress' ] );
    }
    if( isset( $input[ 'social_rss' ] ) ) {
        $input_validated[ 'social_rss' ] = esc_url_raw( $input[ 'social_rss' ] );
    }
    if( isset( $input[ 'social_delicious' ] ) ) {
        $input_validated[ 'social_delicious' ] = esc_url_raw( $input[ 'social_delicious' ] );
    }
    if( isset( $input[ 'social_lastfm' ] ) ) {
        $input_validated[ 'social_lastfm' ] = esc_url_raw( $input[ 'social_lastfm' ] );
    }
    if( isset( $input[ 'social_instagram' ] ) ) {
        $input_validated[ 'social_instagram' ] = esc_url_raw( $input[ 'social_instagram' ] );
    }
    if( isset( $input[ 'social_github' ] ) ) {
        $input_validated[ 'social_github' ] = esc_url_raw( $input[ 'social_github' ] );
    }
    if( isset( $input[ 'social_vkontakte' ] ) ) {
        $input_validated[ 'social_vkontakte' ] = esc_url_raw( $input[ 'social_vkontakte' ] );
    }
    if( isset( $input[ 'social_myworld' ] ) ) {
        $input_validated[ 'social_myworld' ] = esc_url_raw( $input[ 'social_myworld' ] );
    }
    if( isset( $input[ 'social_odnoklassniki' ] ) ) {
        $input_validated[ 'social_odnoklassniki' ] = esc_url_raw( $input[ 'social_odnoklassniki' ] );
    }
    if( isset( $input[ 'social_goodreads' ] ) ) {
        $input_validated[ 'social_goodreads' ] = esc_url_raw( $input[ 'social_goodreads' ] );
    }
    if( isset( $input[ 'social_skype' ] ) ) {
        $input_validated[ 'social_skype' ] = sanitize_text_field( $input[ 'social_skype' ] );
    }
    if( isset( $input[ 'social_soundcloud' ] ) ) {
        $input_validated[ 'social_soundcloud' ] = esc_url_raw( $input[ 'social_soundcloud' ] );
    }
    if( isset( $input[ 'social_email' ] ) ) {
        $input_validated[ 'social_email' ] = sanitize_email( $input[ 'social_email' ] );
    }
    if( isset( $input[ 'social_contact' ] ) ) {
        $input_validated[ 'social_contact' ] = esc_url_raw( $input[ 'social_contact' ] );
    }
    if( isset( $input[ 'social_xing' ] ) ) {
        $input_validated[ 'social_xing' ] = esc_url_raw( $input[ 'social_xing' ] );
    }

    // data validation for Custom Social Icons
    if ( isset( $input[ 'social_custom_qty' ] ) ) {
        $input_validated[ 'social_custom_qty' ] = absint( $input[ 'social_custom_qty' ] ) ? $input [ 'social_custom_qty' ] : 1;
    }
    if ( isset( $input[ 'social_custom_name' ] ) ) {
        $input_validated[ 'social_custom_name' ] = array();
    }
    if ( isset( $input[ 'social_custom_image' ] ) ) {
        $input_validated[ 'social_custom_image' ] = array();
    }
    if ( isset( $input[ 'social_custom_image_hover' ] ) ) {
        $input_validated[ 'social_custom_image_hover' ] = array();
    }
    if ( isset( $input[ 'social_custom_url' ] ) ) {
        $input_validated[ 'social_custom_url' ] = array();
    }
    if ( isset( $input[ 'social_custom_qty' ] ) )   {
        for ( $i = 1; $i <= $input [ 'social_custom_qty' ]; $i++ ) {
            if ( !empty( $input[ 'social_custom_name' ][ $i ] ) ) {
                $input_validated[ 'social_custom_name'][ $i ] = sanitize_text_field($input[ 'social_custom_name'][ $i ]);
            }
            if ( !empty( $input[ 'social_custom_image' ][ $i ] ) ) {
                $input_validated[ 'social_custom_image' ][ $i ] = esc_url_raw($input[ 'social_custom_image' ][ $i ] );
            }
             if ( !empty( $input[ 'social_custom_image_hover' ][ $i ] ) ) {
                $input_validated[ 'social_custom_image_hover' ][ $i ] = esc_url_raw($input[ 'social_custom_image_hover' ][ $i ] );
            }
            if ( !empty( $input[ 'social_custom_url' ][ $i ] ) ) {
                $input_validated[ 'social_custom_url'][ $i ] = esc_url_raw($input[ 'social_custom_url'][ $i ]);
            }
        }
    }


    //Webmaster Tool Verification
    if( isset( $input[ 'google_verification' ] ) ) {
        $input_validated[ 'google_verification' ] = wp_filter_post_kses( $input[ 'google_verification' ] );
    }
    if( isset( $input[ 'yahoo_verification' ] ) ) {
        $input_validated[ 'yahoo_verification' ] = wp_filter_post_kses( $input[ 'yahoo_verification' ] );
    }
    if( isset( $input[ 'bing_verification' ] ) ) {
        $input_validated[ 'bing_verification' ] = wp_filter_post_kses( $input[ 'bing_verification' ] );
    }
    if( isset( $input[ 'analytic_header' ] ) ) {
        $input_validated[ 'analytic_header' ] = wp_kses_stripslashes( $input[ 'analytic_header' ] );
    }
    if( isset( $input[ 'analytic_footer' ] ) ) {
        $input_validated[ 'analytic_footer' ] = wp_kses_stripslashes( $input[ 'analytic_footer' ] );
    }

    // Layout settings verification
    if( isset( $input[ 'sidebar_layout' ] ) ) {
        $input_validated[ 'sidebar_layout' ] = $input[ 'sidebar_layout' ];
    }
    if( isset( $input[ 'content_layout' ] ) ) {
        $input_validated[ 'content_layout' ] = $input[ 'content_layout' ];
    }

    //data validation for more text
    if( isset( $input[ 'more_tag_text' ] ) ) {
        $input_validated[ 'more_tag_text' ] = sanitize_text_field ( $input[ 'more_tag_text' ] );
    }
    //data validation for excerpt length
    if ( isset( $input[ 'excerpt_length' ] ) ) {
        $input_validated[ 'excerpt_length' ] = absint( $input[ 'excerpt_length' ] ) ? $input [ 'excerpt_length' ] : $defaults[ 'excerpt_length' ];
    }
    if ( isset( $input['reset_moretag'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'reset_moretag' ] = $input[ 'reset_moretag' ];
    }

    //Reset Color Options
    if( $input[ 'reset_moretag' ] == 1 ) {
        $input_validated[ 'more_tag_text' ]  = $defaults[ 'more_tag_text' ];
        $input_validated[ 'excerpt_length' ] = $defaults[ 'excerpt_length' ];
        $input_validated[ 'reset_moretag' ]  = "0";

    }


    if( isset( $input[ 'search_display_text' ] ) ) {
        $input_validated[ 'search_display_text' ] = sanitize_text_field( $input[ 'search_display_text' ] ) ? $input [ 'search_display_text' ] : $defaults[ 'search_display_text' ];
    }

    // Data Validation for Featured Image
    if ( isset( $input['featured_image'] ) ) {
        $input_validated[ 'featured_image' ] = $input[ 'featured_image' ];
    }

    if ( isset( $input['reset_layout'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'reset_layout' ] = $input[ 'reset_layout' ];
    }

    //Reset Color Options
    if( $input[ 'reset_layout' ] == 1 ) {
        $input_validated[ 'sidebar_layout' ] = $defaults[ 'sidebar_layout' ];
        $input_validated[ 'content_layout' ] = $defaults[ 'content_layout' ];
        $input_validated[ 'featured_image' ] = $defaults[ 'featured_image' ];
        $input_validated[ 'reset_layout' ]   = "0";
    }



    //Feed Redirect
    if ( isset( $input[ 'feed_url' ] ) ) {
        $input_validated['feed_url'] = esc_url_raw($input['feed_url']);
    }

    //footer text
    if( isset( $input[ 'footer_code' ] ) ) {
        $input_validated['footer_code'] =  stripslashes( wp_filter_post_kses( addslashes ( $input['footer_code'] ) ) );
    }
    if ( isset( $input['reset_footer'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'reset_footer' ] = $input[ 'reset_footer' ];
    }

    //Reset Color Options
    if ( $input[ 'reset_footer' ] == 1 ) {
        $input_validated[ 'footer_code' ] = $defaults[ 'footer_code' ];
        $input_validated[ 'reset_footer' ] = "0";
    }

    // Data Validation for Disable Update Notifier
    if ( isset( $input['disable_notifier'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'disable_notifier' ] = $input[ 'disable_notifier' ];
    }

    // Data Validation for Disable Scroll Up
    if ( isset( $input['disable_scrollup'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'disable_scrollup' ] = $input[ 'disable_scrollup' ];
    }

    //Clearing the theme option cache
    if( function_exists( 'catcheverest_themeoption_invalidate_caches' ) ) catcheverest_themeoption_invalidate_caches();

    return $input_validated;
}


/*
 * Clearing the cache if any changes in Admin Theme Option
 */
function catcheverest_themeoption_invalidate_caches() {
    delete_transient('catcheverest_responsive'); // Responsive design
    delete_transient( 'catcheverest_featured_image' ); // featured header image
    delete_transient( 'catcheverest_inline_css' ); // Custom Inline CSS
    delete_transient( 'catcheverest_post_sliders' ); // featured post slider
    delete_transient( 'catcheverest_page_sliders' ); // featured page slider
    delete_transient( 'catcheverest_category_sliders' ); // featured category slider
    delete_transient( 'catcheverest_image_sliders' ); // featured image slider
    delete_transient( 'catcheverest_homepage_headline' ); // Homepage Headline Message
    delete_transient( 'catcheverest_homepage_featured_content' ); // Homepage Featured Content
    delete_transient( 'catcheverest_footer_content_new' ); // Footer Content New
    delete_transient( 'catcheverest_social_networks' ); // Social Networks
    delete_transient( 'catcheverest_webmaster' ); // scripts which loads on header
    delete_transient( 'catcheverest_footercode' ); // scripts which loads on footer
    delete_transient( 'catcheverest_scrollup' ); // Scroll up Navigation
}


/*
 * Clearing the cache if any changes in post or page
 */
function catcheverest_post_invalidate_caches(){
    delete_transient( 'catcheverest_post_sliders' ); // featured post slider
    delete_transient( 'catcheverest_page_sliders' ); // featured page slider
    delete_transient( 'catcheverest_category_sliders' ); // featured category slider
}
//Add action hook here save post
add_action( 'save_post', 'catcheverest_post_invalidate_caches' );


/**
 * Shortcode to display Footer Image.
 *
 * @uses date() Gets the current year.
 * @return string
 */
function catcheverest_footer_image() {
    if( function_exists( 'catcheverest_footerlogo' ) ) :
        return catcheverest_footerlogo();
    endif;
}


/**
 * Shortcode to display the current year.
 *
 * @uses date() Gets the current year.
 * @return string
 */
function catcheverest_the_year() {
    return esc_attr( date_i18n( __( 'Y', 'catch-everest-pro' ) ) );
}


/**
 * Shortcode to display a link back to the site.
 *
 * @uses get_bloginfo() Gets the site link
 * @return string
 */
function catcheverest_site_link() {
    return '<a href="' . esc_url( home_url( '/' ) ) . '" title="' . esc_attr( get_bloginfo( 'name', 'display' ) ) . '" ><span>' . get_bloginfo( 'name', 'display' ) . '</span></a>';
}


/**
 * Shortcode to display a link to WordPress.org.
 *
 * @return string
 */
function catcheverest_wp_link() {
    return '<a href="http://wordpress.org" target="_blank" title="' . esc_attr__( 'WordPress', 'catch-everest-pro' ) . '"><span>' . __( 'WordPress', 'catch-everest-pro' ) . '</span></a>';
}


/**
 * Shortcode to display a link to Theme Link.
 *
 * @return string
 */
function catcheverest_theme_link() {
    return '<a href="https://catchthemes.com/themes/catch-everest-pro" target="_blank" title="' . esc_attr__( 'Catch Everest Pro', 'catch-everest-pro' ) . '"><span>' . __( 'Catch Everest Pro', 'catch-everest-pro' ) . '</span></a>';
}


/**
 * Returns a link to Theme Shop.
 *
 * @return string
 */
function catcheverest_shop_link() {
    return '<a href="'. esc_url( __( 'https://catchthemes.com', 'catch-everest-pro' ) ) . '" target="_blank" title="' . esc_attr__( 'Catch Themes', 'catch-everest-pro' ) . '"><span>' . __( 'Catch Themes', 'catch-everest-pro' ) . '</span></a>';
}
